@@ -1,43 +1,35 @@
 #! /usr/bin/env python
 import arc
 import sys
-import os
 
 def example():
-    # Creating a UserConfig object with the user's proxy
-    # and the path of the trusted CA certificates
     uc = arc.UserConfig()
-    uc.ProxyPath("/tmp/x509up_u%s" % os.getuid())
-    uc.CACertificatesDirectory("/etc/grid-security/certificates")
+
+    # Create a JobSupervisor to handle all the jobs
+    job_supervisor = arc.JobSupervisor(uc)
 
     # Retrieve all the jobs from this computing element
-    endpoint = arc.Endpoint("piff.hep.lu.se:443/arex", arc.Endpoint.COMPUTINGINFO)
-    print "Querying %s for jobs..." % endpoint.str()
-    jobs = arc.JobContainer()
+    endpoint = arc.Endpoint("https://piff.hep.lu.se:443/arex", arc.Endpoint.JOBLIST)
+    sys.stdout.write("Querying %s for jobs...\n" % endpoint.str())
     retriever = arc.JobListRetriever(uc)
-    retriever.addConsumer(jobs)
+    retriever.addConsumer(job_supervisor)
     retriever.addEndpoint(endpoint)
     retriever.wait()
-    
-    print "%s jobs found" % len(jobs)
-        
-    # Create a JobSupervisor to handle all the jobs
-    job_supervisor = arc.JobSupervisor(uc, jobs)
-    
-    print "Getting job states..."
+
+    sys.stdout.write("%s jobs found\n" % len(job_supervisor.GetAllJobs()))
+
+    sys.stdout.write("Getting job states...\n")
     # Update the states of the jobs
     job_supervisor.Update()
-    
-    # Get the updated jobs
-    jobs = job_supervisor.GetAllJobs()
-    
-    print "The jobs have the following states:", ", ".join([job.State.GetGeneralState() for job in jobs])
-    
+
+    # Print state of updated jobs
+    sys.stdout.write("The jobs have the following states: %s\n"%(", ".join([job.State.GetGeneralState() for job in job_supervisor.GetAllJobs()])))
+
     # Select failed jobs
     job_supervisor.SelectByStatus(["Failed"])
     failed_jobs = job_supervisor.GetSelectedJobs()
-    
-    print "The failed jobs:"
+
+    sys.stdout.write("The failed jobs:\n")
     for job in failed_jobs:
         job.SaveToStream(arc.CPyOstream(sys.stdout), True)
 
@@ -51,4 +43,4 @@ def wait_exit():
 # arc.Logger.getRootLogger().setThreshold(arc.DEBUG)
 
 # run the example
-example()
\ No newline at end of file
+example()
