@@ -13,6 +13,7 @@
 #include <unistd.h>
 
 #include <glibmm/fileutils.h>
+#include <glibmm/miscutils.h>
 
 #include <arc/ArcConfig.h>
 #include <arc/ArcLocation.h>
@@ -34,6 +35,8 @@
 #include "utils.h"
 #include "submit.h"
 
+#include "glibmm-compat.h"
+
 static Arc::Logger logger(Arc::Logger::getRootLogger(), "arcsub");
 
 int test(const Arc::UserConfig& usercfg, Arc::ExecutionTargetSorter& ets, const Arc::JobDescription& testJob, const std::string& jobidfile);
@@ -90,8 +93,9 @@ int RUNMAIN(arctest)(int argc, char **argv) {
     logger.msg(Arc::ERROR, "Failed configuration initialization");
     return 1;
   }
-  if (opt.force_system_ca) usercfg.CAUseSystem(true);
-  if (opt.force_grid_ca) usercfg.CAUseSystem(false);
+  if (opt.force_system_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(false); }
+  if (opt.force_grid_ca) { usercfg.CAUseSystem(false); usercfg.CAUseGrid(true); }
+  if (opt.force_any_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(true); }
   if (opt.allow_insecure_connection) usercfg.TLSAllowInsecure(true);
 
   if (opt.show_plugins) {
@@ -117,7 +121,7 @@ int RUNMAIN(arctest)(int argc, char **argv) {
     if (usercfg.CertificatePath().empty()) {
       std::cout << "  " << Arc::IString("No user-certificate found") << std::endl << std::endl;
     } else {
-      Arc::Credential holder(usercfg.CertificatePath(), "", usercfg.CACertificatesDirectory(), "", usercfg.CAUseSystem());
+      Arc::Credential holder(usercfg.CertificatePath(), "", usercfg.CACertificatesDirectory(), "", usercfg.CAUseSystem(), usercfg.CAUseGrid());
       std::cout << "  " << Arc::IString("Certificate: %s", usercfg.CertificatePath()) << std::endl;
       if (!holder.GetDN().empty()) {
         std::cout << "  " << Arc::IString("Subject name: %s", holder.GetDN()) << std::endl;
@@ -133,7 +137,7 @@ int RUNMAIN(arctest)(int argc, char **argv) {
     if (usercfg.ProxyPath().empty()) {
       std::cout << "  " << Arc::IString("No proxy found") << std::endl << std::endl;
     } else {
-      Arc::Credential holder(usercfg.ProxyPath(), "", usercfg.CACertificatesDirectory(), "", usercfg.CAUseSystem());
+      Arc::Credential holder(usercfg.ProxyPath(), "", usercfg.CACertificatesDirectory(), "", usercfg.CAUseSystem(), usercfg.CAUseGrid());
       std::cout << "  " << Arc::IString("Proxy: %s", usercfg.ProxyPath()) << std::endl;
       std::cout << "  " << Arc::IString("Proxy-subject: %s", holder.GetDN()) << std::endl;
       if (holder.GetEndTime() < now) {
@@ -148,7 +152,7 @@ int RUNMAIN(arctest)(int argc, char **argv) {
     if (!certificate_issuer.empty()) {
       std::cout << Arc::IString("Certificate issuer: %s", certificate_issuer) << std::endl << std::endl;
     }
-    
+
     bool issuer_certificate_found = false;
     std::cout << Arc::IString("CA-certificates installed:") << std::endl;
     Glib::Dir cadir(usercfg.CACertificatesDirectory());
@@ -158,19 +162,19 @@ int RUNMAIN(arctest)(int argc, char **argv) {
       if (Glib::file_test(cafile, Glib::FILE_TEST_IS_REGULAR) && (*it)[(*it).size()-2] == '.' &&
           ((*it)[(*it).size()-1] == '0' || (*it)[(*it).size()-1] == '1' || (*it)[(*it).size()-1] == '2')) {
         
-        Arc::Credential cred(cafile, "", "", "", false);
+        Arc::Credential cred(cafile, "", "", "", false, false);
         std::string dn = cred.GetDN();
         if (dn.empty()) continue;
-          
+
         std::string hash;
         // Only accept certificates with correct hash.
         if (!get_hash_value(cred, hash) || hash != (*it).substr(0, (*it).size()-2)) continue;
-        
+
         if (dn == certificate_issuer) issuer_certificate_found = true;
         std::cout << "  " << dn << std::endl;
       }
     }
-    
+
     if (certificate_issuer.empty()) {
       std::cout << std::endl << Arc::IString("Unable to detect if issuer certificate is installed.") << std::endl;
     }
@@ -280,7 +284,7 @@ int test(const Arc::UserConfig& usercfg, Arc::ExecutionTargetSorter& ets, const
       break;
     }
   }
-  
+
   if (ets.endOfList()) {
     std::cout << Arc::IString("Test failed, no more possible targets") << std::endl;
     submittedJobs.pop_back();
@@ -308,20 +312,20 @@ int dumpjobdescription_arctest_legacy(const Arc::UserConfig& usercfg, Arc::Execu
     std::string jobdesc;
     // Prepare the test jobdescription according to the chosen ExecutionTarget
     if (!preparedTestJob.Prepare(*ets)) {
-      logger.msg(Arc::INFO, "Unable to prepare job description according to needs of the target resource (%s).", ets->ComputingEndpoint->URLString); 
+      logger.msg(Arc::INFO, "Unable to prepare job description according to needs of the target resource (%s).", ets->ComputingEndpoint->URLString);
       continue;
     }
-  
+
     std::string jobdesclang = "emies:adl";
     if (ets->ComputingEndpoint->InterfaceName == "org.nordugrid.gridftpjob") {
       jobdesclang = "nordugrid:xrsl";
     }
-    
+
     if (!preparedTestJob.UnParse(jobdesc, jobdesclang)) {
-      logger.msg(Arc::INFO, "An error occurred during the generation of job description to be sent to %s", ets->ComputingEndpoint->URLString); 
+      logger.msg(Arc::INFO, "An error occurred during the generation of job description to be sent to %s", ets->ComputingEndpoint->URLString);
       continue;
     }
-  
+
     std::cout << Arc::IString("Job description to be sent to %s:", ets->AdminDomain->Name) << std::endl;
     std::cout << jobdesc << std::endl;
     break;
