@@ -9,6 +9,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
+#include <glibmm/fileutils.h>
+#include <glibmm/miscutils.h>
+
 #include <arc/ArcLocation.h>
 #include <arc/OptionParser.h>
 #include <arc/StringConv.h>
@@ -30,6 +33,8 @@
 
 #include "arcproxy.h"
 
+#include "glibmm-compat.h"
+
 using namespace ArcCredential;
 
 #ifdef HAVE_NSS
@@ -69,7 +74,7 @@ static void get_default_nssdb_path(std::vector<std::string>& nss_paths) {
     pf_home = profiles_homes[i];
     struct stat st;
     if(::stat(pf_home.c_str(), &st) != 0) continue;
-    if(!S_ISDIR(st.st_mode)) continue; 
+    if(!S_ISDIR(st.st_mode)) continue;
     if(user.get_uid() != st.st_uid) continue;
     pf_homes.push_back(pf_home);
   }
@@ -80,15 +85,15 @@ static void get_default_nssdb_path(std::vector<std::string>& nss_paths) {
   for(int i=0; i<pf_homes.size(); i++) {
     std::string pf_file = pf_homes[i] + G_DIR_SEPARATOR_S "profiles.ini";
     struct stat st;
-    if(::stat(pf_file.c_str(),&st) != 0) continue; 
-    if(!S_ISREG(st.st_mode)) continue; 
+    if(::stat(pf_file.c_str(),&st) != 0) continue;
+    if(!S_ISREG(st.st_mode)) continue;
     if(user.get_uid() != st.st_uid) continue;
     ini_home[pf_file] = pf_homes[i];
   }
 
-  // All of the reachable profiles.ini files will be parsed to get 
+  // All of the reachable profiles.ini files will be parsed to get
   // the nss configuration information (nss db location).
-  // All of the information about nss db location  will be 
+  // All of the information about nss db location  will be
   // merged together for users to choose
   std::map<std::string, std::string>::iterator it;
   for(it = ini_home.begin(); it != ini_home.end(); ++it) {
@@ -106,14 +111,14 @@ static void get_default_nssdb_path(std::vector<std::string>& nss_paths) {
     for (std::list<std::string>::iterator i = lines.begin(); i != lines.end(); ++i) {
       std::vector<std::string> inivalue;
       Arc::tokenize(*i, inivalue, "=");
-      if((inivalue[0].find("Profile") != std::string::npos) && 
+      if((inivalue[0].find("Profile") != std::string::npos) &&
          (inivalue[0].find("StartWithLast") == std::string::npos)) {
         bool is_relative = false;
         std::string path;
         std::advance(i, 1);
         for(; i != lines.end();) {
           inivalue.clear();
-          Arc::tokenize(*i, inivalue, "=");   
+          Arc::tokenize(*i, inivalue, "=");
           if (inivalue.size() == 2) {
             if (inivalue[0] == "IsRelative") {
               if(inivalue[1] == "1") is_relative = true;
@@ -136,8 +141,8 @@ static void get_default_nssdb_path(std::vector<std::string>& nss_paths) {
       }
     }
   }
-  return; 
-} 
+  return;
+}
 
 static void get_nss_certname(std::string& certname, Arc::Logger& logger) {
   std::list<ArcAuthNSS::certInfo> certInfolist;
@@ -156,7 +161,7 @@ static void get_nss_certname(std::string& certname, Arc::Logger& logger) {
     pos1 = sub_dn.find("CN=");
     if(pos1 != std::string::npos) {
       pos2 = sub_dn.find(",", pos1);
-      if(pos2 != std::string::npos) 
+      if(pos2 != std::string::npos)
         cn_name = " ("+sub_dn.substr(pos1+3, pos2-pos1-3) + ")";
     }
     std::cout<<Arc::IString("Number %d is with nickname: %s%s", n, cert_info.certname, cn_name)<<std::endl;
@@ -273,7 +278,7 @@ static int runmain(int argc, char *argv[]) {
                                     "  issuer - issuer subject name of proxy certificate.\n\n"
                                     "  ca - subject name of CA which issued initial certificate.\n\n"
                                     "  path - file system path to file containing proxy.\n\n"
-                                    "  type - type of proxy certificate.\n"
+                                    "  type - type of proxy certificate.\n\n"
                                     "  validityStart - timestamp when proxy validity starts.\n\n"
                                     "  validityEnd - timestamp when proxy validity ends.\n\n"
                                     "  validityPeriod - duration of proxy validity in seconds.\n\n"
@@ -359,7 +364,7 @@ static int runmain(int argc, char *argv[]) {
 
   bool use_http_comm = false;
   options.AddOption('H', "httpcom", istring("use HTTP communication protocol for contacting VOMS services that provide RESTful access\n"
-                                            "               Note for RESTful access, \'list\' command and multiple VOMS server are not supported\n"), use_http_comm);
+                                            "               Note for RESTful access, \'list\' command and multiple VOMS servers are not supported\n"), use_http_comm);
 
   bool use_old_comm = false;
   options.AddOption('B', "oldcom", istring("use old communication protocol for contacting VOMS services instead of RESTful access\n"), use_old_comm);
@@ -382,18 +387,20 @@ static int runmain(int argc, char *argv[]) {
 
   bool use_empty_passphrase = false; //if use empty passphrase to myproxy serveyr
   options.AddOption('N', "nopassphrase", istring(
-              "don't prompt for a credential passphrase, when retrieve a "
-              "credential from an MyProxy server.\n"
+              "don't prompt for a credential passphrase, when retrieving a "
+              "credential from a MyProxy server.\n"
               "    The precondition of this choice is that the credential was PUT onto\n"
               "    the MyProxy server without a passphrase by using the\n"
               "    -R (--retrievable_by_cert) option.\n"
-              "    This option is specific for the GET command when contacting Myproxy server."),
+              "    This option is specific to the GET command when contacting a Myproxy\n"
+              "    server."),
                     use_empty_passphrase);
-  
+
   std::string retrievable_by_cert; //if use empty passphrase to myproxy server
   options.AddOption('R', "retrievable_by_cert", istring(
               "Allow specified entity to retrieve credential without passphrase.\n"
-              "    This option is specific for the PUT command when contacting Myproxy server."),
+              "    This option is specific to the PUT command when contacting a Myproxy\n"
+              "    server."),
                     istring("string"), retrievable_by_cert);
 
   std::string myproxy_server; //url of MyProxy server
@@ -446,12 +453,17 @@ static int runmain(int argc, char *argv[]) {
   options.AddOption('\0', "systemca",
                     istring("force using CA certificates configuration provided by OpenSSL"),
                     force_system_ca);
-    
+
   bool force_grid_ca = false;
   options.AddOption('\0', "gridca",
                     istring("force using CA certificates configuration for Grid services (typically IGTF)"),
                     force_grid_ca);
 
+  bool force_any_ca = false;
+  options.AddOption('\0', "anyca",
+                    istring("force using CA certificates configuration for Grid services (typically IGTF) and one provided by OpenSSL"),
+                    force_any_ca);
+
   bool allow_insecure_connection = false;
   options.AddOption('\0', "allowinsecureconnection",
                     istring("allow TLS connection which failed verification"),
@@ -498,10 +510,11 @@ static int runmain(int argc, char *argv[]) {
     return EXIT_FAILURE;
   }
 
-  if (force_system_ca) usercfg.CAUseSystem(true);
-  if (force_grid_ca) usercfg.CAUseSystem(false);
+  if (force_system_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(false); }
+  if (force_grid_ca) { usercfg.CAUseSystem(false); usercfg.CAUseGrid(true); }
+  if (force_any_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(true); }
   if (allow_insecure_connection) usercfg.TLSAllowInsecure(true);
- 
+
   if(use_nssdb) {
     usercfg.CertificatePath("");;
     usercfg.KeyPath("");;
@@ -522,9 +535,9 @@ static int runmain(int argc, char *argv[]) {
   // Can proxy be used for? Could not find it in documentation.
   // Key and certificate not needed if only printing proxy information
   if ( (!(Arc::lower(myproxy_command) == "get")) && (!use_nssdb) ) {
-    if((usercfg.CertificatePath().empty() || 
+    if((usercfg.CertificatePath().empty() ||
         (
-         usercfg.KeyPath().empty() && 
+         usercfg.KeyPath().empty() &&
          (usercfg.CertificatePath().find(".p12") == std::string::npos)
         )
        ) && !(info || (infoitemlist.size() > 0) || remove_proxy)) {
@@ -576,7 +589,7 @@ static int runmain(int argc, char *argv[]) {
   }
 
   // Proxy is special case. We either need default or predefined path.
-  // No guessing or testing is needed. 
+  // No guessing or testing is needed.
   // By running credentials initialization once more all set values
   // won't change. But proxy will get default value if not set.
   {
@@ -604,7 +617,7 @@ static int runmain(int argc, char *argv[]) {
   }
 
   const Arc::Time now;
-  
+
   if (remove_proxy) {
     if (proxy_path.empty()) {
       logger.msg(Arc::ERROR, "Cannot find the path of the proxy file, "
@@ -641,7 +654,7 @@ static int runmain(int argc, char *argv[]) {
                  "Please make sure this file exists.", proxy_path);
       return EXIT_FAILURE;
     }
-    Arc::Credential holder(proxy_path, "", "", "", false);
+    Arc::Credential holder(proxy_path, "", "", "", false, false);
     if(!holder.GetCert()) {
       logger.msg(Arc::ERROR, "Cannot process proxy file at %s.", proxy_path);
       return EXIT_FAILURE;
@@ -662,7 +675,7 @@ static int runmain(int argc, char *argv[]) {
 
     Arc::VOMSTrustList voms_trust_dn;
     voms_trust_dn.AddRegex(".*");
-    res = parseVOMSAC(holder, ca_dir, "", voms_dir, voms_trust_dn, voms_attributes, true, true);
+    res = parseVOMSAC(holder, usercfg.CAUseGrid() ? ca_dir : "", "", usercfg.CAUseSystem(), voms_dir, voms_trust_dn, voms_attributes, true, true);
     // Not printing error message because parseVOMSAC will print everything itself
     //if (!res) logger.msg(Arc::ERROR, "VOMS attribute parsing failed");
     for(int n = 0; n<voms_attributes.size(); ++n) {
@@ -739,8 +752,8 @@ static int runmain(int argc, char *argv[]) {
           }
 
           //std::cout << "attribute : "<<voms_attributes[n].attributes[i]<<std::endl;
-          //do not display those attributes that have already been displayed 
-          //(this can happen when there are multiple voms server )
+          //do not display those attributes that have already been displayed
+          //(this can happen when there are multiple voms servers)
         }
         Arc::Time ct;
         if(ct < voms_attributes[n].from) {
@@ -774,7 +787,7 @@ static int runmain(int argc, char *argv[]) {
                  "Please make sure this file exists.", proxy_path);
       return EXIT_FAILURE;
     }
-    Arc::Credential holder(proxy_path, "", "", "", false);
+    Arc::Credential holder(proxy_path, "", "", "", false, false);
     if(!holder.GetCert()) {
       logger.msg(Arc::ERROR, "Cannot process proxy file at %s.", proxy_path);
       return EXIT_FAILURE;
@@ -782,7 +795,7 @@ static int runmain(int argc, char *argv[]) {
     Arc::VOMSTrustList voms_trust_dn;
     voms_trust_dn.AddRegex(".*");
     std::vector<Arc::VOMSACInfo> voms_attributes;
-    parseVOMSAC(holder, ca_dir, "", voms_dir, voms_trust_dn, voms_attributes, true, true);
+    parseVOMSAC(holder, usercfg.CAUseGrid() ? ca_dir : "", "", usercfg.CAUseSystem(), voms_dir, voms_trust_dn, voms_attributes, true, true);
     bool unknownInfo = false;
     for(std::list<std::string>::iterator ii = infoitemlist.begin();
                            ii != infoitemlist.end(); ++ii) {
@@ -864,7 +877,7 @@ static int runmain(int argc, char *argv[]) {
     return EXIT_SUCCESS;
   }
 
-  if ((cert_path.empty() || key_path.empty()) && 
+  if ((cert_path.empty() || key_path.empty()) &&
       (Arc::lower(myproxy_command) == "put")) {
     if (cert_path.empty())
       logger.msg(Arc::ERROR, "Cannot find the user certificate path, "
@@ -929,7 +942,7 @@ static int runmain(int argc, char *argv[]) {
       if(pos == std::string::npos) {
         logger.msg(Arc::ERROR, "Cannot parse password source %s "
                    "it must be of source_type or source_type:data format. "
-                   "Supported source types are int,stdin,stream,file.", pass);
+                   "Supported source types are int, stdin, stream, file.", pass);
         return EXIT_FAILURE;
       }
       std::string data = pass.substr(pos + 1);
@@ -947,7 +960,7 @@ static int runmain(int argc, char *argv[]) {
         }
       } else {
         logger.msg(Arc::ERROR, "Cannot parse password source type %s. "
-                   "Supported source types are int,stdin,stream,file.", pass);
+                   "Supported source types are int, stdin, stream, file.", pass);
         return EXIT_FAILURE;
       }
     }
@@ -977,12 +990,12 @@ static int runmain(int argc, char *argv[]) {
   Arc::Time validityStart = now; // now by default
   Arc::Period validityPeriod(12*60*60);
   if (Arc::lower(myproxy_command) == "put") {
-    //For myproxy PUT operation, the proxy should be 7 days according to the default 
+    //For myproxy PUT operation, the proxy should be 7 days according to the default
     //definition in myproxy implementation.
     validityPeriod = 7*24*60*60;
   }
   // Acquire constraints. Check for valid values and conflicts.
-  if((!constraints["validityStart"].empty()) && 
+  if((!constraints["validityStart"].empty()) &&
      (!constraints["validityEnd"].empty()) &&
      (!constraints["validityPeriod"].empty())) {
     std::cerr << Arc::IString("The start, end and period can't be set simultaneously") << std::endl;
@@ -1044,7 +1057,7 @@ static int runmain(int argc, char *argv[]) {
   } else {
     if(validityPeriod < vomsACvalidityPeriod) vomsACvalidityPeriod = validityPeriod;
     // It is strange that VOMS AC may be valid less than proxy itself.
-    // Maybe it would be more correct to have it valid by default from 
+    // Maybe it would be more correct to have it valid by default from
     // now till validityEnd.
   }
   std::string voms_period = Arc::tostring(vomsACvalidityPeriod.GetPeriod());
@@ -1136,7 +1149,7 @@ static int runmain(int argc, char *argv[]) {
       if(!Arc::TmpFileCreate(tmp_proxy_path,"")) return EXIT_FAILURE;
 
       get_nss_certname(issuername, logger);
-      
+
       // Create tmp proxy cert
       int duration = 12;
       res = ArcAuthNSS::nssCreateCert(proxy_csrfile, issuername, NULL, duration, "", tmp_proxy_path, ascii);
@@ -1183,7 +1196,7 @@ static int runmain(int argc, char *argv[]) {
     // Create proxy with VOMS AC
     std::string proxy_certfile = "myproxy.pem";
 
-    // Let user to choose which credential to use 
+    // Let user to choose which credential to use
     if(issuername.empty()) get_nss_certname(issuername, logger);
     std::cout<<Arc::IString("Certificate to use is: %s", issuername)<<std::endl;
 
@@ -1199,7 +1212,7 @@ static int runmain(int argc, char *argv[]) {
     res = ArcAuthNSS::nssImportCert(*passsources[pass_nss], proxy_certfile, proxy_certname, trusts, ascii);
     if(!res) return EXIT_FAILURE;
 
-    //Compose the proxy certificate 
+    //Compose the proxy certificate
     if(!proxy_path.empty())Arc::SetEnv("X509_USER_PROXY", proxy_path);
     Arc::UserConfig usercfg(conffile,
         Arc::initializeCredentialsType(Arc::initializeCredentialsType::NotTryCredentials));
@@ -1207,8 +1220,9 @@ static int runmain(int argc, char *argv[]) {
       logger.msg(Arc::ERROR, "Failed configuration initialization.");
       return EXIT_FAILURE;
     }
-    if (force_system_ca) usercfg.CAUseSystem(true);
-    if (force_grid_ca) usercfg.CAUseSystem(false);
+    if (force_system_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(false); }
+    if (force_grid_ca) { usercfg.CAUseSystem(false); usercfg.CAUseGrid(true); }
+    if (force_any_ca) { usercfg.CAUseSystem(true); usercfg.CAUseGrid(true); }
     if(proxy_path.empty()) proxy_path = usercfg.ProxyPath();
     usercfg.ProxyPath(proxy_path);
     std::string cert_file = "cert.pem";
@@ -1233,7 +1247,7 @@ static int runmain(int argc, char *argv[]) {
     proxy_cred_str.append(proxy_privk_str).append(eec_cert_str);
     write_proxy_file(proxy_path, proxy_cred_str);
 
-    Arc::Credential proxy_cred(proxy_path, proxy_path, "", "", false);
+    Arc::Credential proxy_cred(proxy_path, proxy_path, "", "", false, false);
     Arc::Time left = proxy_cred.GetEndTime();
     std::cout << Arc::IString("Proxy generation succeeded") << std::endl;
     std::cout << Arc::IString("Your proxy is valid until: %s", left.str(Arc::UserTime)) << std::endl;
@@ -1260,20 +1274,20 @@ static int runmain(int argc, char *argv[]) {
   }
 
   if (!myproxy_command.empty() && (Arc::lower(myproxy_command) != "put")) {
-    bool res = contact_myproxy_server(myproxy_server, myproxy_command, 
-      user_name, use_empty_passphrase, myproxy_period, retrievable_by_cert, 
+    bool res = contact_myproxy_server(myproxy_server, myproxy_command,
+      user_name, use_empty_passphrase, myproxy_period, retrievable_by_cert,
       proxy_start, proxy_period, vomslist, vomses_path, proxy_path, usercfg, logger);
     if (res && (Arc::lower(myproxy_command) == "get") && (!vomslist.empty())) {
       // IF the myproxy command is "Get", and voms command is given,
       // then we need to check if the proxy returned from myproxy server
       // includes VOMS AC, if not, we will use the returned proxy to
-      // directly contact VOMS server to generate a proxy-on-proxy with 
+      // directly contact VOMS server to generate a proxy-on-proxy with
       // VOMS AC included.
-      Arc::Credential holder(proxy_path, "", "", "", false);
+      Arc::Credential holder(proxy_path, "", "", "", false, false);
       Arc::VOMSTrustList voms_trust_dn;
       voms_trust_dn.AddRegex(".*");
       std::vector<Arc::VOMSACInfo> voms_attributes;
-      bool r = parseVOMSAC(holder, ca_dir, "", voms_dir, voms_trust_dn, voms_attributes, true, true);
+      bool r = parseVOMSAC(holder, usercfg.CAUseSystem() ? ca_dir : "", "", usercfg.CAUseSystem(), voms_dir, voms_trust_dn, voms_attributes, true, true);
       if (!r) logger.msg(Arc::ERROR, "VOMS attribute parsing failed");
       if(voms_attributes.size() == 0) {
         logger.msg(Arc::INFO, "Myproxy server did not return proxy with VOMS AC included");
@@ -1281,9 +1295,9 @@ static int runmain(int argc, char *argv[]) {
         contact_voms_servers(vomscmdlist, orderlist, vomses_path, use_gsi_comm,
             use_http_comm || !use_old_comm, voms_period, usercfg, logger, proxy_path, vomsacseq);
         if(!vomsacseq.empty()) {
-          Arc::Credential signer(proxy_path, proxy_path, "", "", false);
+          Arc::Credential signer(proxy_path, proxy_path, "", "", false, false);
           std::string proxy_cert;
-          create_proxy(proxy_cert, signer, policy, proxy_start, proxy_period, 
+          create_proxy(proxy_cert, signer, policy, proxy_start, proxy_period,
               vomsacseq, keybits, signing_algorithm);
           write_proxy_file(proxy_path, proxy_cert);
         }
@@ -1295,7 +1309,7 @@ static int runmain(int argc, char *argv[]) {
 
   //Create proxy or voms proxy
   try {
-    Arc::Credential signer(cert_path, key_path, "", "", false, *passsources[pass_private_key]);
+    Arc::Credential signer(cert_path, key_path, "", "", false, false, *passsources[pass_private_key]);
     if (signer.GetIdentityName().empty()) {
       std::cerr << Arc::IString("Proxy generation failed: No valid certificate found.") << std::endl;
       return EXIT_FAILURE;
@@ -1338,16 +1352,16 @@ static int runmain(int argc, char *argv[]) {
     }
 
     std::string proxy_cert;
-    create_proxy(proxy_cert, signer, policy, proxy_start, proxy_period,      
+    create_proxy(proxy_cert, signer, policy, proxy_start, proxy_period,
         vomsacseq, keybits, signing_algorithm);
 
-    //If myproxy command is "Put", then the proxy path is set to /tmp/myproxy-proxy.uid.pid 
+    //If myproxy command is "Put", then the proxy path is set to /tmp/myproxy-proxy.uid.pid
     if (Arc::lower(myproxy_command) == "put")
       proxy_path = Glib::build_filename(Glib::get_tmp_dir(), "myproxy-proxy."
                    + Arc::tostring(user.get_uid()) + Arc::tostring((int)(getpid())));
     write_proxy_file(proxy_path,proxy_cert);
 
-    Arc::Credential proxy_cred(proxy_path, proxy_path, "", "", false);
+    Arc::Credential proxy_cred(proxy_path, proxy_path, "", "", false, false);
     Arc::Time left = proxy_cred.GetEndTime();
     std::cout << Arc::IString("Proxy generation succeeded") << std::endl;
     std::cout << Arc::IString("Your proxy is valid until: %s", left.str(Arc::UserTime)) << std::endl;
