@@ -636,12 +636,20 @@ class ARCRest:
             if walltime > maxWallTime:
                 raise MatchmakingError(f"Walltime {walltime} higher than max walltime {maxWallTime} for queue {queue}")
 
+    @classmethod
+    def _get(cls, source, name):
+        val = source.get(name)
+        if val is None:
+            return {}
+        if not isinstance(val, list):
+            return val
+        if val:
+            return val[0]
+        return {}
+
     def _findQueue(self, ceInfo, queue):
-        compShares = ceInfo.get("Domains", {}) \
-                           .get("AdminDomain", {}) \
-                           .get("Services", {}) \
-                           .get("ComputingService", {}) \
-                           .get("ComputingShare", [])
+        compShares = self._get(self._get(self._get(self._get(ceInfo, "Domains"), "AdminDomain"), "Services"), "ComputingService").get("ComputingShare", [])
+
         if not compShares:
             return None
 
@@ -662,13 +670,7 @@ class ARCRest:
         return None
 
     def _findRuntimes(self, ceInfo):
-        appenvs = ceInfo.get("Domains", {}) \
-                        .get("AdminDomain", {}) \
-                        .get("Services", {}) \
-                        .get("ComputingService", {}) \
-                        .get("ComputingManager", {}) \
-                        .get("ApplicationEnvironments", {}) \
-                        .get("ApplicationEnvironment", [])
+        appenvs = self._get(self._get(self._get(self._get(self._get(self._get(ceInfo, "Domains"), "AdminDomain"), "Services"), "ComputingService"), "ComputingManager"), "ApplicationEnvironments").get("ApplicationEnvironment", [])
 
         # /rest/1.0 compatibility
         if not isinstance(appenvs, list):
