@@ -20,6 +20,8 @@ namespace ArcDMCGridFTP {
 
   using namespace Arc;
 
+  static Logger logger_(Logger::getRootLogger(), "DataPoint.GridFTPDelegate");
+
 
   DataPointGridFTPDelegate::DataPointGridFTPDelegate(const URL& url, const UserConfig& usercfg, PluginArgument* parg)
     : DataPointDelegate((Arc::ArcLocation::GetLibDir()+G_DIR_SEPARATOR_S+"arc-dmcgridftp").c_str(), std::list<std::string>(), url, usercfg, parg) {
@@ -58,6 +60,12 @@ namespace ArcDMCGridFTP {
     return true;
   }
 
+  bool DataPointGridFTPDelegate::WriteOutOfOrder() const {
+    // Globus gridftp library does not accept random offsets in stream mode.
+    // See DataPointGridFTP::set_attributes() on why following combination is used.
+    return (is_secure && !force_passive);
+  }
+
 
 } // namespace ArcDMCGridFTP
 
