@@ -3,10 +3,6 @@
 #include <config.h>
 #endif
 
-#ifdef WIN32 
-#include <arc/win32.h>
-#endif
-
 #include "SRM22Client.h"
 
 #include <arc/StringConv.h>
