@@ -8,8 +8,6 @@
 #include <iostream>
 #include <string>
 
-#include <glibmm/miscutils.h>
-
 #include <arc/ArcLocation.h>
 #include <arc/User.h>
 #include "ArcConfig.h"
@@ -73,7 +71,7 @@ namespace Arc {
     if(v.empty()) return true; // default
     for(int n = 0;opts[n];++n) {
       if(v == opts[n]) { val = n; return true; };
-    }; 
+    };
     return false;
   }
 
@@ -92,7 +90,7 @@ namespace Arc {
   }
 
 
-  BaseConfig::BaseConfig() : plugin_paths(ArcLocation::GetPlugins()), systemca(false), tlsallowinsecure(false),
+  BaseConfig::BaseConfig() : plugin_paths(ArcLocation::GetPlugins()), systemca(false), gridca(true), tlsallowinsecure(false),
                              otoken_for_auth(true), cert_for_auth(true) {}
 
   void BaseConfig::AddPluginsPath(const std::string& path) {
@@ -135,8 +133,12 @@ namespace Arc {
     otoken = token;
   }
 
-  void BaseConfig::SetSystemCA(bool use_default) {
-    systemca = use_default;
+  void BaseConfig::SetSystemCA(bool use) {
+    systemca = use;
+  }
+
+  void BaseConfig::SetGridCA(bool use) {
+    gridca = use;
   }
 
   void BaseConfig::SetTLSAllowInsecure(bool allow_insecure) {
