@@ -11,19 +11,25 @@
 #include <pwd.h>
 #include <grp.h>
 
+#include <algorithm>
 #include <fstream>
-#include <glibmm.h>
-#include <arc/FileUtils.h>
+
+#include <glibmm/fileutils.h>
+#include <glibmm/miscutils.h>
 
 #include <arc/ArcLocation.h>
+#include <arc/FileUtils.h>
 #include <arc/IniConfig.h>
 #include <arc/Logger.h>
 #include <arc/StringConv.h>
 #include <arc/URL.h>
 #include <arc/User.h>
 #include <arc/Utils.h>
+
 #include "UserConfig.h"
 
+#include "glibmm-compat.h"
+
 #define HANDLESTRATT(ATT, SETTER) \
   if (common[ATT]) {\
     SETTER((std::string)common[ATT]);\
@@ -75,7 +81,7 @@ namespace Arc {
         if((user.Name() != *member) && ((pwd_p == NULL) || (user.Name() != root_pwd.pw_name))) {
           return file_test_wrong_permissions;
         }
-	++member;
+        ++member;
       }
     }
     return file_test_success;
@@ -105,7 +111,7 @@ namespace Arc {
   }
 
   static file_test_status private_file_test(const std::string& path, const User& user) {
-    // Check if access to file content is protected. It must be readable and writable by our 
+    // Check if access to file content is protected. It must be readable and writable by our
     // user only with exception of root.
     struct stat st;
     if(::stat(path.c_str(),&st) != 0) return file_test_missing;
@@ -250,7 +256,7 @@ namespace Arc {
   }
 
   UserConfig::UserConfig(initializeCredentialsType initializeCredentials)
-    : timeout(0), keySize(0), ok(false), caUseSystem(false), tlsAllowInsecure(false), initializeCredentials(initializeCredentials), authType(AuthTypeUndefined) {
+    : timeout(0), keySize(0), caUseSystem(false), caUseGrid(true), tlsAllowInsecure(false), authType(AuthTypeUndefined), ok(false), initializeCredentials(initializeCredentials) {
     if (!InitializeCredentials(initializeCredentials)) {
       return;
     }
@@ -263,7 +269,7 @@ namespace Arc {
   UserConfig::UserConfig(const std::string& conffile,
                          initializeCredentialsType initializeCredentials,
                          bool loadSysConfig)
-    : timeout(0), keySize(0), ok(false), caUseSystem(false), tlsAllowInsecure(false), initializeCredentials(initializeCredentials), authType(AuthTypeUndefined)  {
+    : timeout(0), keySize(0), caUseSystem(false), caUseGrid(true), tlsAllowInsecure(false), authType(AuthTypeUndefined), ok(false), initializeCredentials(initializeCredentials) {
     setDefaults();
     if (loadSysConfig) {
       if (Glib::file_test(SYSCONFIG(), Glib::FILE_TEST_IS_REGULAR)) {
@@ -309,7 +315,7 @@ namespace Arc {
 
   UserConfig::UserConfig(const std::string& conffile, const std::string& jfile,
                          initializeCredentialsType initializeCredentials, bool loadSysConfig)
-    : timeout(0), keySize(0), ok(false), caUseSystem(false), tlsAllowInsecure(false), initializeCredentials(initializeCredentials), authType(AuthTypeUndefined)  {
+    : timeout(0), keySize(0), caUseSystem(false), caUseGrid(true), tlsAllowInsecure(false), authType(AuthTypeUndefined), ok(false), initializeCredentials(initializeCredentials) {
     // If job list file have been specified, try to initialize it, and
     // if it fails then this object is non-valid (ok = false).
     setDefaults();
@@ -379,8 +385,9 @@ namespace Arc {
       }
     }
     ccfg.SetSystemCA(caUseSystem);
+    ccfg.SetGridCA(caUseGrid);
     ccfg.SetTLSAllowInsecure(tlsAllowInsecure);
-    if(!caUseSystem)
+    if(caUseGrid)
       ccfg.AddCADir(caCertificatesDirectory);
 
     switch(authType) {
@@ -462,10 +469,18 @@ namespace Arc {
 
   bool UserConfig::InitializeCredentials(initializeCredentialsType initializeCredentials) {
     std::string ca_policy = GetEnv("X509_CERT_POLICY");
-    if (ca_policy == "grid") {
+    if (ca_policy == "any") {
+      caUseSystem = true;
+      caUseGrid = true;
+    } else if (ca_policy == "grid") {
       caUseSystem = false;
+      caUseGrid = true;
     } else if(ca_policy == "system") {
       caUseSystem = true;
+      caUseGrid = false;
+    } else if(ca_policy == "none") {
+      caUseSystem = false;
+      caUseGrid = false;
     }
 
     if(initializeCredentials == initializeCredentialsType::SkipCredentials) return true;
@@ -646,7 +661,7 @@ namespace Arc {
     }
 
     if(!noca) {
-      if (!caUseSystem) {
+      if (caUseGrid) {
         std::string ca_dir = GetEnv("X509_CERT_DIR");
         //std::cerr<<"-- ca_dir = "<<ca_dir<<std::endl;
         if (!ca_dir.empty()) {
@@ -860,7 +875,8 @@ namespace Arc {
           }
           HANDLESTRATT("cacertificatepath", CACertificatePath)
           HANDLESTRATT("cacertificatesdirectory", CACertificatesDirectory)
-	  HANDLESTRATT("causesystem", CAUseSystem)
+          HANDLESTRATT("causesystem", CAUseSystem)
+          HANDLESTRATT("causegrid", CAUseGrid)
           if (common["certificatelifetime"]) {
             certificateLifeTime = Period((std::string)common["certificatelifetime"]);
             common["certificatelifetime"].Destroy();
@@ -997,6 +1013,7 @@ namespace Arc {
     if (!caCertificatesDirectory.empty())
       file << "cacertificatesdirectory = " << caCertificatesDirectory << std::endl;
     file << "causesystem = " << (caUseSystem?1:0) << std::endl;
+    file << "causegrid = " << (caUseGrid?1:0) << std::endl;
     if (certificateLifeTime > 0)
       file << "certificatelifetime = " << certificateLifeTime << std::endl;
     if (slcs)
@@ -1131,17 +1148,6 @@ namespace Arc {
   }
 
   bool UserConfig::copyFile(const std::string& source, const std::string& destination) {
-/*
-TODO: Make FileUtils function to this
-#ifdef HAVE_GIOMM
-    try {
-      return Gio::File::create_for_path(source)->copy(Gio::File::create_for_path(destination), Gio::FILE_COPY_NONE);
-    } catch (Gio::Error e) {
-      logger.msg(WARNING, "%s", (std::string)e.what());
-      return false;
-    }
-#else
-*/
     std::ifstream ifsSource(source.c_str(), std::ios::in | std::ios::binary);
     if (!ifsSource)
       return false;
@@ -1159,7 +1165,6 @@ TODO: Make FileUtils function to this
     }
 
     return true;
-//#endif
   }
 
   bool UserConfig::UtilsDirPath(const std::string& dir) {
@@ -1294,7 +1299,7 @@ static std::string cert_file_fix(const std::string& old_file,std::string& new_fi
     SET_NEW_VAR_FILE("X509_USER_CERT",cfg.CertificatePath(),x509_user_cert_new);
     SET_NEW_VAR_FILE("X509_USER_PROXY",cfg.ProxyPath(),x509_user_proxy_new);
     SET_NEW_VAR("X509_CERT_DIR",cfg.CACertificatesDirectory());
-    SET_NEW_VAR("X509_CERT_POLICY",(cfg.CAUseSystem()?"system":"grid"));
+    SET_NEW_VAR("X509_CERT_POLICY",(cfg.CAUseSystem()?(cfg.CAUseGrid()?"any":"system"):(cfg.CAUseGrid()?"grid":"none")));
     EnvLockWrap(false);
   }
 
