@@ -1,4 +1,8 @@
 // -*- indent-tabs-mode: nil -*-
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 
 #include <fstream>
 
