@@ -35,10 +35,11 @@ namespace Arc {
     trusted_ca_dir_ = cfg.cadir;
     trusted_ca_file_ = cfg.cafile;
     trusted_ca_system_ = cfg.systemca;
+    trusted_ca_grid_ = cfg.gridca;
     if (!cert_file_.empty() && !privkey_file_.empty())
-      signer_ = new Credential(cert_file_, privkey_file_, trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_);
+      signer_ = new Credential(cert_file_, privkey_file_, trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_, trusted_ca_grid_);
     else if (!proxy_file_.empty())
-      signer_ = new Credential(proxy_file_, "", trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_);
+      signer_ = new Credential(proxy_file_, "", trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_, trusted_ca_grid_);
   }
 
   ClientX509Delegation::~ClientX509Delegation() {
@@ -183,7 +184,7 @@ namespace Arc {
       std::string signedcert;
       //std::cout<<"X509 Request: \n"<<getProxyReqReturnValue<<std::endl;
       proxy.InquireRequest(getProxyReqReturnValue);
-      proxy.SetProxyPolicy("gsi2", "", "", -1);
+      proxy.SetProxyPolicy("rfc", "inheritAll", "", -1);
       if (!(signer_->SignRequest(&proxy, signedcert))) {
         logger.msg(ERROR, "DelegateProxy failed");
         return false;
@@ -291,7 +292,7 @@ namespace Arc {
           return false;
         }
 
-        Credential proxy_cred(delegation_cert, privkey_str, trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_, "", false);
+        Credential proxy_cred(delegation_cert, privkey_str, trusted_ca_dir_, trusted_ca_file_, trusted_ca_system_, trusted_ca_grid_, "", false);
         proxy_cred.OutputCertificate(delegation_cred);
         proxy_cred.OutputPrivatekey(delegation_cred);
         proxy_cred.OutputCertificateChain(delegation_cred);
