@@ -13,7 +13,9 @@
 #include <unistd.h>
 #include <utime.h>
 
-#include <glibmm.h>
+#include <glibmm/fileutils.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/random.h>
 
 #include <arc/DateTime.h>
 #include <arc/FileLock.h>
@@ -59,7 +61,7 @@ namespace Arc {
   DataMover::~DataMover() {
     Cancel();
     // Wait for Transfer() to finish with lock
-    Glib::Mutex::Lock lock(lock_);
+    std::unique_lock<std::mutex> lock(lock_);
   }
 
   bool DataMover::verbose() {
@@ -288,9 +290,10 @@ namespace Arc {
       cacheable = true;
       try {
         // TODO (important) load credential in unified way or 
-        // use already loaded one
+        // use already loaded one.
         Credential ci(source.GetUserConfig().ProxyPath(), source.GetUserConfig().ProxyPath(),
-                      source.GetUserConfig().CACertificatesDirectory(), "", source.GetUserConfig().CAUseSystem());
+                      source.GetUserConfig().CACertificatesDirectory(), "",
+                      source.GetUserConfig().CAUseSystem(), source.GetUserConfig().CAUseGrid());
         dn = ci.GetIdentityName();
         exp_time = ci.GetEndTime();
       } catch (CredentialError& e) {
@@ -452,7 +455,7 @@ namespace Arc {
     DataStatus res = DataStatus::TransferError;
     int try_num;
     for (try_num = 0;; try_num++) { /* cycle for retries */
-      Glib::Mutex::Lock lock(lock_);
+      std::unique_lock<std::mutex> lock(lock_);
       logger.msg(VERBOSE, "DataMover: cycle");
       if ((try_num != 0) && (!do_retries && (!do_retries_retryable || !res.Retryable()))) {
         logger.msg(VERBOSE, "DataMover: no retries requested - exit");
