@@ -278,10 +278,18 @@ namespace Arc {
     /**
      * Sets status type to s and errno to EARCOTHER if s is an error state.
      */
-    DataStatus operator=(const DataStatusType& s) {
+    DataStatus& operator=(const DataStatusType& s) {
       status = s;
       Errno = 0;
       if (!Passed()) Errno = EARCOTHER;
+      desc.clear();
+      return *this;
+    }
+
+    DataStatus& operator=(const DataStatus& s) {
+      status = s.status;
+      Errno = s.Errno;
+      desc = s.desc;
       return *this;
     }
 
@@ -308,6 +316,11 @@ namespace Arc {
      */
     bool Retryable() const;
 
+    /// Get error status code.
+    DataStatusType GetStatus() const {
+      return status;
+    }
+
     /// Set the error number.
     void SetErrno(int error_no) {
       Errno = error_no;
