@@ -16,13 +16,13 @@ namespace Arc {
 class InformationInterface {
  protected:
   /** Mutex used to protect access to Get methods in multi-threaded env. */
-  Glib::Mutex lock_;
+  std::mutex lock_;
   bool to_lock_;
   /** This method is called by this object's Process method.
-    Real implementation of this class should return (sub)tree 
+    Real implementation of this class should return (sub)tree
     of XML document. This method may be called multiple times
-    per single Process call. Here @path is a set on XML element 
-    names specifying how to reach requested node(s).  */  
+    per single Process call. Here @path is a set on XML element
+    names specifying how to reach requested node(s).  */
   virtual void Get(const std::list<std::string>& path,XMLNodeContainer& result);
   virtual void Get(XMLNode xpath,XMLNodeContainer& result);
  public:
@@ -32,7 +32,7 @@ class InformationInterface {
 };
 
 /// Information System document container and processor.
-/** This class inherits form InformationInterface and offers 
+/** This class inherits form InformationInterface and offers
   container for storing informational XML document. */
 class InformationContainer: public InformationInterface {
  protected:
@@ -42,16 +42,16 @@ class InformationContainer: public InformationInterface {
   virtual void Get(XMLNode xpath,XMLNodeContainer& result);
  public:
   InformationContainer(void);
-  /** Creates an instance with XML document @doc. 
+  /** Creates an instance with XML document @doc.
     If @copy is true this method makes a copy of @doc for internal use. */
   InformationContainer(XMLNode doc,bool copy = false);
   virtual ~InformationContainer(void);
   /** Get a lock on contained XML document.
-    To be used in multi-threaded environment. Do not forget to 
+    To be used in multi-threaded environment. Do not forget to
     release it with  Release() */
   XMLNode Acquire(void);
   void Release(void);
-  /** Replaces internal XML document with @doc. 
+  /** Replaces internal XML document with @doc.
     If @copy is true this method makes a copy of @doc for internal use. */
   void Assign(XMLNode doc,bool copy = false);
 };
