@@ -6,7 +6,6 @@
 #include <list>
 #include <glibmm/module.h>
 #include <arc/XMLNode.h>
-#include <arc/Thread.h>
 #include <arc/Logger.h>
 
 namespace Arc {
@@ -38,7 +37,7 @@ typedef void (*arc_module_destructor_func)(Glib::Module*, ModuleManager*);
   and not load them multiple times. But creating multiple instances
   is not prohibited.
    Instance of this class handles loading of shared libraries through
-  call to load() method. All loaded libraries are remembered internally 
+  call to load() method. All loaded libraries are remembered internally
   and by default are unloaded when instance of this class is destroyed.
   Sometimes it is not safe to unload library. In such case makePersistent()
   for this library must be called.
@@ -48,16 +47,16 @@ typedef void (*arc_module_destructor_func)(Glib::Module*, ModuleManager*);
   libraries persistent in memory.
    Before unloading library from memory __arc_module_destructor__ is
   called if present.
-   Every loaded library has load counter associated. Each call to 
+   Every loaded library has load counter associated. Each call to
   load() for specific library increases that counter and unload() decreases
-  it. Library is unloaded when counter reaches zero. When instance of 
+  it. Library is unloaded when counter reaches zero. When instance of
   ModuleManager is destroyed all load counters are reset to 0 and libraries
   are unloaded unless claimed to stay persistent in memory.
    Each library also has usage counter associated. Those counters are increased
   and decreased by use() and unuse() methods. This counter is used to claim usage
-  of code provided by loaded library. It is automatically increased and decreased 
-  in constructor and destructor of Plugin class. Having non-zero usage counter 
-  prevents library from being unloaded. 
+  of code provided by loaded library. It is automatically increased and decreased
+  in constructor and destructor of Plugin class. Having non-zero usage counter
+  prevents library from being unloaded.
    Please note that destructor of ModuleManager waits for all usage counters to
   reach zero. This is especially useful in multithreaded environments. To avoid
   dealocks make sure Plugins loaded by instance of ModuleManager are destroyed
@@ -99,7 +98,7 @@ class ModuleManager
         typedef std::map<std::string, LoadableModuleDescription> plugin_cache_t;
         typedef std::list<LoadableModuleDescription> plugin_trash_t;
 
-        Glib::Mutex mlock;
+        std::mutex mlock;
         static Logger logger;
         std::list<std::string> plugin_dir; /** collection of path to directory for modules */
         plugin_cache_t plugin_cache; /** Cache of handles of loaded modules */
