@@ -43,13 +43,13 @@ namespace Arc {
     valid_ = true;
   }
 
-  JWSE::JWSE(std::string const& jwseCompact): valid_(false), header_(NULL, &cJSON_Delete), keyOrigin_(NoKey) {
+  JWSE::JWSE(std::string const& jwseCompact, UserConfig& userconfig): valid_(false), header_(NULL, &cJSON_Delete), keyOrigin_(NoKey) {
     OpenSSLInit();
 
-    (void)Input(jwseCompact);
+    (void)Input(jwseCompact, userconfig);
   }
 
-  bool JWSE::Input(std::string const& jwseCompact) {
+  bool JWSE::Input(std::string const& jwseCompact, UserConfig& userconfig) {
     Cleanup();
 
     logger_.msg(DEBUG, "JWSE::Input: token: %s", jwseCompact);
@@ -123,7 +123,7 @@ namespace Arc {
       }
 
       // Signature
-      if(!ExtractPublicKey()) return false;
+      if(!ExtractPublicKey(userconfig)) return false;
       char const* signatureStart = pos;
       char const* signatureEnd = jwseCompact.c_str() + jwseCompact.length();
       std::string signature = Base64::decodeURLSafe(signatureStart, signatureEnd-signatureStart);
@@ -170,6 +170,8 @@ namespace Arc {
       } else if(strcmp(algObject->valuestring, "PS512") == 0) {
         verifyResult = VerifyRSASSAPSS("SHA512", joseStart, payloadEnd-joseStart,
                          reinterpret_cast<unsigned char const*>(signature.c_str()), signature.length());
+      } else {
+        logger_.msg(DEBUG, "JWSE::Input: JWS: signature algorithn not supported: %s",algObject->valuestring);
       }
 /*
    | RS256        | RSASSA-PKCS1-v1_5 using       | Recommended        |
@@ -362,7 +364,24 @@ namespace Arc {
     cJSON_AddItemToObject(header_.Ptr(), name, cJSON_CreateString(value));
   }
 
+  std::set<std::string> JWSE::ClaimNames() const {
+    std::set<std::string> names;
+    if(!content_)
+      return names;
+    for(int n = 0;; ++n) {
+      cJSON const * param = cJSON_GetArrayItem(content_.Ptr(),n);
+      if(!param) break;
+      if(param->string) {
+	names.insert(param->string);
+      }
+    }
+
+    return names;
+  }
+
   cJSON const* JWSE::Claim(char const* name) const {
+    if(!name)
+      return NULL;
     if(!content_)
       return NULL;
     cJSON const* param = cJSON_GetObjectItem(const_cast<cJSON*>(content_.Ptr()), name);
@@ -371,7 +390,6 @@ namespace Arc {
     return param;
   }
 
-
   void JWSE::Claim(char const* name, cJSON const* value) {
     if(!content_)
       return;
