@@ -9,10 +9,6 @@
 #include "otokens.h"
 #include "jwse_private.h"
 
-#if OPENSSL_VERSION_NUMBER < 0x10100000L
-#define EVP_MD_CTX_new EVP_MD_CTX_create
-#define EVP_MD_CTX_free EVP_MD_CTX_destroy
-#endif
 
 namespace Arc {
 
