@@ -28,9 +28,9 @@ public:
   /** Destructor. */
   virtual ~PayloadTLSStream(void);
   
-  void HandleError(int code = SSL_ERROR_NONE);
-  static void HandleError(Logger& logger,int code = SSL_ERROR_NONE);
-  static void ClearError(void);
+  //void HandleError(int code = SSL_ERROR_NONE);
+  //static void HandleError(Logger& logger,int code = SSL_ERROR_NONE);
+  //void ClearError(void);
 
   virtual bool Get(char* buf,int& size);
   virtual bool Get(std::string& buf);
@@ -45,6 +45,8 @@ public:
   virtual Size_t Pos(void) const { return 0; };
   virtual Size_t Size(void) const { return 0; };
   virtual Size_t Limit(void) const { return 0; };
+  virtual void SetFailure(const std::string& err);
+  virtual void SetFailure(int code = SSL_ERROR_NONE);
 
   /**Get peer certificate from the established ssl.
     Obtained X509 object is owned by this instance and becomes invalid
