@@ -2,6 +2,7 @@
 #include <config.h>
 #endif
 
+#include <algorithm>
 #include <iostream>
 
 #include <vector>
@@ -69,7 +70,7 @@ AuthResult AuthUser::match_otokens(const char* line) {
               default_otokens_ = otokens_t();
               default_otokens_.subject = v->subject;
               default_otokens_.issuer = v->issuer;
-	      if(audience != "*") default_otokens_.audiences.push_back(audience);
+              if(audience != "*") default_otokens_.audiences.push_back(audience);
               if(scope != "*") default_otokens_.scopes.push_back(scope);
               if(group != "*") default_otokens_.groups.push_back(group);
               return AAA_POSITIVE_MATCH;
@@ -118,6 +119,7 @@ class Expression {
 public:
   virtual std::string const & EvaluateValue() { throw Exception("Undefined EvaluateValue was called"); }
   virtual bool EvaluateBool(EvalContext & context) { throw Exception("Undefined EvaluateBool was called"); }
+  virtual ~Expression() {}
 private:
   static std::string EmptyString;
 };
@@ -154,56 +156,56 @@ public:
         //logger.msg(Arc::DEBUG, "Evaluate operator |: right: %d",right_->EvaluateBool(context));
         if(left_->EvaluateBool(context)) return true;
         if(right_->EvaluateBool(context)) return true;
-	return false;
-	break;
+        return false;
+        break;
       case '&':
         //logger.msg(Arc::DEBUG, "Evaluate operator &: left: %d",left_->EvaluateBool(context));
         //logger.msg(Arc::DEBUG, "Evaluate operator &: right: %d",right_->EvaluateBool(context));
         if(!left_->EvaluateBool(context)) return false;
         if(!right_->EvaluateBool(context)) return false;
-	return true;
-	break;
+        return true;
+        break;
       case '^':
         return !(left_->EvaluateBool(context) == right_->EvaluateBool(context));
-	break;
+        break;
       case '=':
-	{
+        {
           // Left value is claim name
-	  // Right value is expected claim value
+          // Right value is expected claim value
           std::string lvalue = left_->EvaluateValue();
           logger.msg(Arc::DEBUG, "Evaluate operator =: left: %s",lvalue);
           logger.msg(Arc::DEBUG, "Evaluate operator =: right: %s",right_->EvaluateValue());
-	  if(!lvalue.empty()) {
+          if(!lvalue.empty()) {
             EvalContext::iterator itValues = context.find(lvalue);
-	    if(itValues != context.end()) {
+            if(itValues != context.end()) {
               for(std::list<std::string>::iterator itValue = itValues->second.begin(); itValue != itValues->second.end(); ++itValue) {
                 logger.msg(Arc::DEBUG, "Evaluate operator =: left from context: %s",*itValue);
                 if(*itValue == right_->EvaluateValue()) return true;
-	      }
-	    }
-	  }
+              }
+            }
+          }
           return false;
-	}
-	break;
+        }
+        break;
       case '~':
         {
           // Left value is claim name
-	  // Right value is regular expression to match
+          // Right value is regular expression to match
           std::string lvalue = left_->EvaluateValue();
-	  if(!lvalue.empty()) {
+          if(!lvalue.empty()) {
             EvalContext::iterator itValues = context.find(lvalue);
-	    if(itValues != context.end()) {
+            if(itValues != context.end()) {
               Arc::RegularExpression regexp(right_->EvaluateValue());
               for(std::list<std::string>::iterator itValue = itValues->second.begin(); itValue != itValues->second.end(); ++itValue) {
-                if(regexp.match(left_->EvaluateValue())) return true;
-	      }
-	    }
-	  }
+                if(regexp.match(*itValue)) return true;
+              }
+            }
+          }
           return false;
         }
         break;
       default:
-	break;
+        break;
     }
     throw Exception((std::string("Unknown binary operation ") + op_ + " was evaluated").c_str());
   }
@@ -220,7 +222,6 @@ private:
 };
 
 
-
 class Token {
 public:
   virtual bool isValue() const { return false; }
@@ -229,6 +230,7 @@ public:
   virtual Expression* MakeExpression() { throw Exception("Undefined value MakeExpression was called"); }
   virtual Expression* MakeExpression(Expression* right) { throw Exception("Undefined unary MakeExpression was called"); }
   virtual Expression* MakeExpression(Expression* left, Expression* right) { throw Exception("Undefined binary MakeExpression was called"); }
+  virtual ~Token() {}
 };
 
 class TokenOperator: public Token {
@@ -268,6 +270,34 @@ private:
   std::string value_;
 };
 
+class TokenQuotedString: public Token {
+public:
+  static Token* Parse(char const * & str, char esc = '\\') {
+    std::string value;
+    char mark = str[0];
+    ++str;
+    while(true) {
+      char const * pos = strchr(str, mark);
+      if(!pos) throw Exception("Missing closing quotation mark");
+      std::size_t len = pos-str;
+      value.append(str, len);
+      str = pos+1;
+      if((len > 0) && (value[len-1] != esc)) break;
+      value[len-1] = mark;  
+    }
+    return new TokenQuotedString(value);
+  }
+  virtual bool isValue() const { return true; }
+  virtual Expression* MakeExpression() { return new ExpressionValue(value_); }
+
+private:
+  TokenQuotedString(std::string& value) {
+    value_.swap(value);
+    logger.msg(Arc::DEBUG, "Quoted string token: %s",value_);
+  };
+  std::string value_;
+};
+
 class TokenSequence: public Token {
 public:
   static Token* Parse(char const * & str, bool tillBracket = false) {
@@ -276,7 +306,7 @@ public:
     while(true) {
       str = SkipWS(str);
       if(!str) {
-	if(tillBracket) throw Exception("Missing closing bracket");
+        if(tillBracket) throw Exception("Missing closing bracket");
         break;
       }
 
@@ -293,9 +323,7 @@ public:
         ++str;
         token->tokens_.push_back(TokenSequence::Parse(str, true));
       } else if(c == '"') {
-        ++str;
-        token->tokens_.push_back(TokenString::Parse(str, tillBracket?")\"":"\""));
-        ++str;
+        token->tokens_.push_back(TokenQuotedString::Parse(str));
       } else {
         token->tokens_.push_back(TokenString::Parse(str, tillBracket?") \t!|&^=~":" \t!|&^=~"));
       }
@@ -335,10 +363,10 @@ public:
       exprLeft = (*itTokenLeft)->MakeExpression();
       // smash unary
       while(itTokenLeft != itTokenLeftStart) {
-        Arc::AutoPointer<Expression> newExpr((*itTokenLeft)->MakeExpression(exprLeft.Ptr()));
-	exprLeft.Release();
-	exprLeft = newExpr;
         --itTokenLeft;
+        Arc::AutoPointer<Expression> newExpr((*itTokenLeft)->MakeExpression(exprLeft.Ptr()));
+        exprLeft.Release();
+        exprLeft = newExpr;
       }
     }
 
@@ -348,7 +376,7 @@ public:
       std::list<Token*>::iterator itTokenBinary(itToken);
       ++itToken;
       if(itToken == tokens_.end()) throw Exception("Missing right side of expression");
-      
+
       Arc::AutoPointer<Expression> exprRight;
       {
         std::list<Token*>::iterator itTokenRightStart(itToken);
@@ -365,10 +393,10 @@ public:
         exprRight = (*itTokenRight)->MakeExpression();
         // smash unary
         while(itTokenRight != itTokenRightStart) {
-	  Arc::AutoPointer<Expression> newExpr((*itTokenRight)->MakeExpression(exprRight.Ptr()));
-	  exprRight.Release();
-	  exprRight = newExpr;
           --itTokenRight;
+          Arc::AutoPointer<Expression> newExpr((*itTokenRight)->MakeExpression(exprRight.Ptr()));
+          exprRight.Release();
+          exprRight = newExpr;
         }
       }
 
@@ -390,38 +418,38 @@ AuthResult AuthUser::match_ftokens(const char* line) {
   if(otokens_data_.empty()) return AAA_NO_MATCH;
   if(!line) return AAA_NO_MATCH;
   logger.msg(Arc::DEBUG, "Matching tokens expression: %s",line);
-  Arc::AutoPointer<LogicExp::Token> token(LogicExp::TokenSequence::Parse(line));
-  if(!token) {
-    logger.msg(Arc::DEBUG, "Failed to parse expression");
-    return AAA_NO_MATCH;
-  }
-  Arc::AutoPointer<LogicExp::Expression> expr(token->MakeExpression());
-  if(!expr) return AAA_NO_MATCH;
-  for(int idx = 0; idx < otokens_data_.size(); ++idx) {
-    otokens_t& token_info = otokens_data_[idx];
-    std::map< std::string,std::list<std::string> >& claims = token_info.claims;
-    for(std::map< std::string,std::list<std::string> >::iterator claim = claims.begin(); claim != claims.end(); ++claim) {
-      std::list<std::string>& values = claim->second;
-      if(values.empty()) {
-        logger.msg(Arc::DEBUG, "%s: <empty>", claim->first);
-      } else {
-        logger.msg(Arc::DEBUG, "%s: %s", claim->first, values.front());
-        for(std::list<std::string>::iterator value =  values.begin();;) {
-          ++value;
-          if(value == values.end()) break;
-          logger.msg(Arc::DEBUG, "      %s", *value);
-	}
-      }
+  try {
+    Arc::AutoPointer<LogicExp::Token> token(LogicExp::TokenSequence::Parse(line));
+    if(!token) {
+      logger.msg(Arc::DEBUG, "Failed to parse expression");
+      return AAA_NO_MATCH;
     }
-    try {
+    Arc::AutoPointer<LogicExp::Expression> expr(token->MakeExpression());
+    if(!expr) return AAA_NO_MATCH;
+    for(int idx = 0; idx < otokens_data_.size(); ++idx) {
+      otokens_t& token_info = otokens_data_[idx];
+      std::map< std::string,std::list<std::string> >& claims = token_info.claims;
+      for(std::map< std::string,std::list<std::string> >::iterator claim = claims.begin(); claim != claims.end(); ++claim) {
+        std::list<std::string>& values = claim->second;
+        if(values.empty()) {
+          logger.msg(Arc::DEBUG, "%s: <empty>", claim->first);
+        } else {
+          logger.msg(Arc::DEBUG, "%s: %s", claim->first, values.front());
+          for(std::list<std::string>::iterator value =  values.begin();;) {
+            ++value;
+            if(value == values.end()) break;
+            logger.msg(Arc::DEBUG, "      %s", *value);
+          }
+        }
+      }
       if(expr->EvaluateBool(claims)) {
         logger.msg(Arc::DEBUG, "Expression matched");
         return AAA_POSITIVE_MATCH;
       }
-    } catch(std::exception& exc) {
-      logger.msg(Arc::DEBUG, "Failed to evaluate expression: %s",exc.what());
-      return AAA_FAILURE;
     }
+  } catch(std::exception& exc) {
+    logger.msg(Arc::ERROR, "Failed to evaluate expression: %s",exc.what());
+    return AAA_FAILURE;
   }
   logger.msg(Arc::DEBUG, "Expression failed to matched");
   return AAA_NO_MATCH;
