@@ -5,7 +5,6 @@
 #include <stdexcept>
 
 #include <arc/XMLNode.h>
-#include <arc/Thread.h>
 #include <arc/ArcConfig.h>
 #include <arc/Logger.h>
 #include <arc/URL.h>
@@ -35,7 +34,7 @@ Plugin* PDPServiceInvoker::get_pdpservice_invoker(PluginArgument* arg) {
 }
 
 PDPServiceInvoker::PDPServiceInvoker(Config* cfg,Arc::PluginArgument* parg):PDP(cfg,parg), client(NULL), 
-  system_ca(false), is_xacml(false), is_saml(false) {
+  system_ca(false), grid_ca(true), is_xacml(false), is_saml(false) {
   XMLNode filter = (*cfg)["Filter"];
   if((bool)filter) {
     XMLNode select_attr = filter["Select"];
@@ -50,7 +49,7 @@ PDPServiceInvoker::PDPServiceInvoker(Config* cfg,Arc::PluginArgument* parg):PDP(
   std::string url_str;
   url_str = (std::string)((*cfg)["Endpoint"]);
   Arc::URL url(url_str);
-  
+
   std::cout<<"URL: "<<url_str<<std::endl;
 
   Arc::MCCConfig mcc_cfg;
@@ -61,6 +60,7 @@ PDPServiceInvoker::PDPServiceInvoker(Config* cfg,Arc::PluginArgument* parg):PDP(
   ca_dir = (std::string)((*cfg)["CACertificatesDir"]);
   ca_file = (std::string)((*cfg)["CACertificatePath"]);
   system_ca = (((std::string)((*cfg)["SystemCA"])) == "true");
+  grid_ca = !(((std::string)((*cfg)["GridCA"])) == "false");
   mcc_cfg.AddPrivateKey(key_path);
   mcc_cfg.AddCertificate(cert_path);
   mcc_cfg.AddProxy(proxy_path);
@@ -131,7 +131,7 @@ PDPStatus PDPServiceInvoker::isPermitted(Message *msg) const {
     authz_query.NewAttribute("Version") = std::string("2.0");
 
     Arc::Credential cred(cert_path.empty() ? proxy_path : cert_path,
-         cert_path.empty() ? proxy_path : key_path, ca_dir, ca_file, system_ca);
+         cert_path.empty() ? proxy_path : key_path, ca_dir, ca_file, system_ca, grid_ca);
     std::string local_dn_str = cred.GetDN();
     std::string local_dn = Arc::convert_to_rdn(local_dn_str);
     std::string issuer_name = local_dn;
@@ -195,12 +195,12 @@ PDPStatus PDPServiceInvoker::isPermitted(Message *msg) const {
       std::string str;
       resp->GetXML(str);
       logger.msg(Arc::INFO, "Response: %s", str);
-  
+
       // TODO: Fix namespaces
       authz_res=(std::string)((*resp)["pdp:GetPolicyDecisionResponse"]["response:Response"]["response:AuthZResult"]);
 
       delete resp;
-    } 
+    }
 
     if(authz_res == "PERMIT") { logger.msg(Arc::INFO,"Authorized from remote pdp service"); return true; }
     else { logger.msg(Arc::INFO,"Unauthorized from remote pdp service"); return false; }
