@@ -6,7 +6,6 @@
 #include <sys/types.h>
 
 #include <arc/XMLNode.h>
-#include <arc/Thread.h>
 #include <arc/ArcConfig.h>
 #include <arc/Logger.h>
 
@@ -53,7 +52,7 @@ PDPStatus SimpleListPDP::isPermitted(Message *msg) const {
   if(fs.fail()) {
     logger.msg(ERROR, "The policy file setup for simplelist.pdp does not exist, please check location attribute for simplelist PDP node in service configuration");
     return PDPStatus(PDPStatus::STATUS_DENY, "Misconfigured authorization list");
-  }   
+  }
 
   while (fs.good()) {
     std::string::size_type p;
