@@ -19,7 +19,7 @@ class SimpleListPDP : public PDP {
   static Arc::Plugin* get_simplelist_pdp(Arc::PluginArgument *arg);
   SimpleListPDP(Arc::Config* cfg, Arc::PluginArgument* parg);
   virtual ~SimpleListPDP() {};
-  virtual bool isPermitted(Arc::Message *msg) const;
+  virtual PDPStatus isPermitted(Arc::Message *msg) const;
  private:
   std::string location;
   std::list<std::string> dns;
