@@ -49,7 +49,6 @@ namespace DataStaging {
        destination_endpoint(destination_url, cfg),
        source_url_str(source_url.str()),
        destination_url_str(destination_url.str()),
-       use_acix(false),
        user(uid),
        parent_job_id(jobid),
        priority(50),
@@ -164,6 +163,7 @@ namespace DataStaging {
     // empty cache and map info
     cache_file.clear();
     mapped_source.clear();
+    mapped_destination.clear();
     bytes_transferred = 0;
     transfer_time = 0;
     reset_error_status();
