@@ -258,9 +258,6 @@ namespace DataStaging {
     /// Cache state for this DTR
     CacheState cache_state;
 
-    /// Whether ACIX is used as a source
-    bool use_acix;
-
     /// Local user information
     Arc::User user;
 
@@ -302,6 +299,10 @@ namespace DataStaging {
     /** Delivery should check if this is set and if so use this as source. */
     std::string mapped_source;
 
+    /// The file that the current destination is mapped to.
+    /** Delivery should check if this is set and if so use this as destination. */
+    std::string mapped_destination;
+
     /// Status of the DTR
     DTRStatus status;
 
@@ -591,16 +592,16 @@ namespace DataStaging {
     /// Get the cache state
     CacheState get_cache_state() const { return cache_state; };
 
-    /// Set whether ACIX is a source
-    void set_use_acix(bool acix) { use_acix = acix; };
-    /// Get whether ACIX is a source
-    bool get_use_acix() const { return use_acix; };
-
-    /// Set the mapped file
+    /// Set the mapped source file
     void set_mapped_source(const std::string& file = "") { mapped_source = file; };
-    /// Get the mapped file
+    /// Get the mapped source file
     std::string get_mapped_source() const { return mapped_source; };
 
+    /// Set the mapped destination file
+    void set_mapped_destination(const std::string& file = "") { mapped_destination = file; };
+    /// Get the mapped destination file
+    std::string get_mapped_destination() const { return mapped_destination; };
+
     /// Find the DTR owner
     StagingProcesses get_owner() const { return current_owner; };
      
