@@ -50,7 +50,7 @@ namespace DataStaging {
       return;
     }
     {
-      Glib::Mutex::Lock lock(lock_);
+      std::unique_lock<std::mutex> lock(lock_);
       // Generate options for child
       std::list<std::string> args;
       std::string execpath = Arc::ArcLocation::GetLibDir()+G_DIR_SEPARATOR_S+"DataStagingDelivery";
@@ -102,8 +102,8 @@ namespace DataStaging {
         // If file-based credentials are not required then send through stdin
         if (!dtr->get_usercfg().OToken().empty()) {
           stdin_ = "token ";
-	  stdin_ += dtr->get_usercfg().OToken();
-	} else {
+          stdin_ += dtr->get_usercfg().OToken();
+        } else {
           stdin_ = "x509 ";
           stdin_ += dtr->get_usercfg().CredentialString();
         }
@@ -133,6 +133,10 @@ namespace DataStaging {
       args.push_back(std::string("casystem=")+Arc::tostring((int)dtr->get_usercfg().CAUseSystem()));
       args.push_back("--dopt");
       args.push_back(std::string("casystem=")+Arc::tostring((int)dtr->get_usercfg().CAUseSystem()));
+      args.push_back("--sopt");
+      args.push_back(std::string("cagrid=")+Arc::tostring((int)dtr->get_usercfg().CAUseGrid()));
+      args.push_back("--dopt");
+      args.push_back(std::string("cagrid=")+Arc::tostring((int)dtr->get_usercfg().CAUseGrid()));
       args.push_back("--topt");
       args.push_back(std::string("minspeed=")+Arc::tostring(transfer_params.min_current_bandwidth));
       args.push_back("--topt");
@@ -198,7 +202,7 @@ namespace DataStaging {
 
   DataDeliveryLocalComm::~DataDeliveryLocalComm(void) {
     {
-      Glib::Mutex::Lock lock(lock_);
+      std::unique_lock<std::mutex> lock(lock_);
       if(child_) {
         child_->Kill(10); // Give it a chance
         delete child_; child_=NULL;  // And then kill for sure
@@ -213,7 +217,7 @@ namespace DataStaging {
   }
 
   void DataDeliveryLocalComm::PullStatus(void) {
-    Glib::Mutex::Lock lock(lock_);
+    std::unique_lock<std::mutex> lock(lock_);
     if(!child_) return;
     for(;;) {
       if(status_pos_ < sizeof(status_buf_)) {
