@@ -23,6 +23,9 @@ namespace DataStaging {
     /// Read from stdout of child to get status
     virtual void PullStatus();
 
+    /// Returns identifier of delivery handler - localhost.
+    virtual std::string DeliveryId() const;
+
     /// Returns "/" since local Delivery can access everywhere
     static bool CheckComm(DTR_ptr dtr, std::vector<std::string>& allowed_dirs, std::string& load_avg);
 
