@@ -5,7 +5,6 @@
 #include <map>
 #include <sqlite3.h>
 #include <arc/Logger.h>
-#include <arc/Thread.h>
 
 #include "AccountingDB.h"
 
@@ -26,7 +25,7 @@ namespace ARex {
         bool addJobEvent(aar_jobevent_t& events, const std::string& jobid);
       private:
         static Arc::Logger logger;
-        Glib::Mutex lock_;
+        std::mutex lock_;
         // General Name-ID tables
         name_id_map_t db_queue;
         name_id_map_t db_users;
@@ -61,8 +60,8 @@ namespace ARex {
         /// General helper to execute UPDATE statement
         bool GeneralSQLUpdate(const std::string& sql);
 
-        /// General helper that return accounting database ID for requested iname 
-        /** 
+        /// General helper that return accounting database ID for requested iname
+        /**
          * Performs lookup in the specified table with the [ID, Name] columns
          * Updates the name_id_map map of the object
          **/
