@@ -5,8 +5,6 @@
 #include <iostream>
 #include <fstream>
 
-#include <glibmm.h>
-
 #include <arc/FileUtils.h>
 #include <arc/StringConv.h>
 #include <arc/URL.h>
@@ -309,7 +307,7 @@ bool JobDescriptionHandler::write_grami(const Arc::JobDescription& arc_job_desc,
 
     }else{
       f<<"joboption_count=1"<<std::endl;
-    } 
+    }
   }
 
   if (arc_job_desc.Resources.SlotRequirement.ExclusiveExecution == Arc::SlotRequirementType::EE_TRUE){
