@@ -40,7 +40,11 @@ public:
   /// Parse the job description at the given file into job_desc and
   /// arc_job_desc. Optionally check acl file and put result into
   /// returned object
-  JobReqResult parse_job_req(JobLocalDescription &job_desc,Arc::JobDescription& arc_job_desc,const std::string &fname,bool check_acl=false) const;
+  JobReqResult parse_job_req_from_file(JobLocalDescription &job_desc,Arc::JobDescription& arc_job_desc,const std::string &fname,bool check_acl=false) const;
+  /// Parse the job description from the given string into job_desc and
+  /// arc_job_desc. Optionally check acl file and put result into
+  /// returned object
+  JobReqResult parse_job_req_from_mem(JobLocalDescription &job_desc,Arc::JobDescription& arc_job_desc,const std::string &desc_str,bool check_acl=false) const;
   /// Parse the job description for job_id into job_desc. Optionally check
   /// acl file and put result into returned object
   JobReqResult parse_job_req(const JobId &job_id,JobLocalDescription &job_desc,bool check_acl=false) const;
@@ -50,15 +54,17 @@ public:
   /// Parse job description into job_desc and write .local, .input and .output files
   bool process_job_req(const GMJob &job,JobLocalDescription &job_desc) const;
   /// Write .grami file after parsing job description file
-  bool write_grami(const GMJob &job,const char *opt_add = NULL) const;
+  bool write_grami(GMJob &job,const char *opt_add = NULL) const;
   /// Write .grami from information in arc_job_desc and job
-  bool write_grami(const Arc::JobDescription& arc_job_desc, const GMJob& job, const char* opt_add) const;
+  bool write_grami(const Arc::JobDescription& arc_job_desc, GMJob& job, const char* opt_add) const;
   /// Get the local LRMS job id corresponding to A-REX job_id
   std::string get_local_id(const JobId &job_id) const;
   /// Set executable bits on appropriate files for the given job
   bool set_execs(const GMJob &job) const;
 
 private:
+  JobReqResult parse_job_req_internal(JobLocalDescription &job_desc,Arc::JobDescription const& arc_job_desc,bool check_acl=false) const;
+
   /// Read and parse job description from file and update the job description reference.
   /** @param fname filename of the job description file.
    * @param desc a reference to a Arc::JobDescription which is filled on success,
