@@ -18,7 +18,7 @@ namespace ARex {
 
 class HeartBeatMetrics {
  private:
-  Glib::RecMutex lock;
+  std::recursive_mutex lock;
   bool enabled;
   std::string config_filename;
   std::string tool_path;
@@ -30,7 +30,7 @@ class HeartBeatMetrics {
   double totalfree;
 
   bool time_update;
-  
+
   Arc::Run *proc;
   std::string proc_stderr;
 
