@@ -18,7 +18,7 @@ namespace ARex {
 
 class SpaceMetrics {
  private:
-  Glib::RecMutex lock;
+  std::recursive_mutex lock;
   bool enabled;
   std::string config_filename;
   std::string tool_path;
@@ -30,7 +30,7 @@ class SpaceMetrics {
   double freeSession;
   double totalFreeSession;
   bool freeSession_update;
-  
+
   Arc::Run *proc;
   std::string proc_stderr;
 
