@@ -7,7 +7,7 @@ namespace ARex {
   Starts external process smtp-send.sh to send mail to user
   about changes in job's status.
 */
-bool send_mail(const GMJob &job, const GMConfig& config);
+bool send_mail(GMJob &job, const GMConfig& config);
 
 } // namespace ARex
 
