@@ -9,6 +9,7 @@ use strict;
 
 # The returned hash looks something like this:
 
+# TODO: review this schema, there is a lot of legacy stuff to fix.
 our $j = { 'jobID' => {
             gmuser             => '*',
             # from .local
@@ -84,34 +85,31 @@ sub switchEffectiveUser {
 }
 
 sub collect {
-    my ($controls, $remotegmdirs, $nojobs) = @_;
+    my ($arex, $nojobs) = @_;
 
     my $gmjobs = {};
-    while (my ($user, $control) = each %$controls) {
-        switchEffectiveUser($user);
-        my $controldir = $control->{controldir};
-        my $newjobs = get_gmjobs($controldir, $nojobs);
-        $newjobs->{$_}{gmuser} = $user for keys %$newjobs;
-        $gmjobs->{$_} = $newjobs->{$_} for keys %$newjobs;
-    }
-
-    # switch to root or to gridftpd user?
-    switchEffectiveUser('.');
-
-    if ($remotegmdirs) {
-        for my $pair (@$remotegmdirs) {
-            my ($controldir, $sessiondir) = split ' ', $pair;
-            my $newjobs = get_gmjobs($controldir, $nojobs);
-            $gmjobs->{$_} = $newjobs->{$_} for keys %$newjobs;
-        }
-    }
-    
-    # switch back to root
-    switchEffectiveUser('.');
+    my $user = $arex->{user};
+    # Disabling user switching for now, runs as the same user as a-rex
+    #switchEffectiveUser($user);
+    my $controldir = $arex->{controldir};
+    my $newjobs = get_gmjobs($controldir, $nojobs);
+    # TODO: can this be removed? What is this one fetching exaclty?
+    $newjobs->{$_}{gmuser} = $user for keys %$newjobs;
+    $gmjobs->{$_} = $newjobs->{$_} for keys %$newjobs;
 
     return $gmjobs;
 }
 
+# Given the controldir path, the jobid and a suffix
+# returns a path to that job in the fragmented controldir.
+sub control_path {
+    my ($controldir, $jobid, $suffix) = @_;
+    
+    my ($a,$b,$c,$d) = unpack("A3A3A3A3", $jobid);
+    my $path = "$controldir/jobs/$a/$b/$c/$d/$suffix";
+    
+    return $path;
+}
 
 sub get_gmjobs {
 
@@ -133,7 +131,7 @@ sub get_gmjobs {
     my @allfiles = grep /\.status/, readdir JOBDIR;
     closedir JOBDIR;
 
-    my @gridmanager_jobs = map {$_=~m/job\.(.+)\.status/; $_=$1;} @allfiles;
+    my @gridmanager_jobs = map {$_=~m/(.+)\.status/; $_=$1;} @allfiles;
 
     # count job IDs to scan
     $jobstoscan = $jobstoscan + @gridmanager_jobs;
@@ -141,14 +139,17 @@ sub get_gmjobs {
 
     foreach my $ID (@gridmanager_jobs) {
 
+        $log->debug("Scanning job $ID");
+
         my $job = $gmjobs{$ID} = {};
 
-        my $gmjob_local       = $controldir."/job.".$ID.".local";
-        my $gmjob_status      = $controlsubdir."/job.".$ID.".status";
-        my $gmjob_failed      = $controldir."/job.".$ID.".failed";
-        my $gmjob_description = $controldir."/job.".$ID.".description";
-        my $gmjob_grami       = $controldir."/job.".$ID.".grami";
-        my $gmjob_diag        = $controldir."/job.".$ID.".diag";
+        my $gmjob_status      = $controlsubdir."/".$ID.".status";
+        my $jobpath           = control_path($controldir, $ID, "");
+        my $gmjob_local       = "$jobpath"."local";
+        my $gmjob_failed      = "$jobpath"."failed";
+        my $gmjob_description = "$jobpath"."description";
+        my $gmjob_grami       = "$jobpath"."grami";
+        my $gmjob_diag        = "$jobpath"."diag";
 
         unless ( open (GMJOB_LOCAL, "<$gmjob_local") ) {
             $log->debug( "Job $ID: Can't read jobfile $gmjob_local, skipping job" );
@@ -163,9 +164,8 @@ sub get_gmjobs {
         # parse the content of the job.ID.local into the %gmjobs hash
         foreach my $line (@local_allines) {
             if ($line=~m/^(\w+)=(.+)$/) {
-                # TODO: multiple activityid support. 
-                # is this still used? if not, remove the code.
-                # looking at trunk it doesn't seem to exist anymore.
+                # multiple activityid support. 
+                # Still in CPP codebase, see grid-manager/files/ControlFileContent.cpp, so keeping it here.
                 if ($1 eq "activityid") {
                     push @{$job->{activityid}}, $2;
                 } else {
