@@ -6,9 +6,7 @@ use strict;
 use LogUtils;
 
 our $rte_options_schema = {
-        pgkdatadir     => '',
-        configfile     => '',
-        runtimedir     => '*',
+        controldir     => '',
 };
 
 our $rte_info_schema = {
@@ -23,10 +21,10 @@ our $log = LogUtils->getLogger(__PACKAGE__);
 sub collect($) {
     my ($options) = @_;
 
-    return {} unless $options->{runtimedir};
-
     my $rtes = {};
-    add_static_rtes($options->{runtimedir}, $rtes);
+
+    # enabled RTEs in controldir
+    add_static_rtes("$options->{controldir}/rte/enabled/", $rtes) if $options->{controldir};
 
     return $rtes;
 }
@@ -35,11 +33,11 @@ sub collect($) {
 sub add_static_rtes {
     my ($runtimedir, $rtes) = @_;
     unless (opendir DIR, $runtimedir) {
-       $log->warning("Can't access runtimedir: $runtimedir: $!");
+       $log->debug("Can't access runtimedir: $runtimedir: $!");
        return;
     }
     closedir DIR;
-    my $cmd = "find '$runtimedir' -type f ! -name '.*' ! -name '*~'";
+    my $cmd = "find '$runtimedir' ! -type d ! -name '.*' ! -name '*~' -exec test -e {} \\; -print";
     unless (open RTE, "$cmd |") {
        $log->warning("Failed to run: $cmd");
        return;
@@ -55,9 +53,8 @@ sub add_static_rtes {
 #### TEST ##### TEST ##### TEST ##### TEST ##### TEST ##### TEST ##### TEST ####
 
 sub test {
-    my $options = { pkgdatadir => '/scratch/adrianta/arc1/share/arc',
-                    runtimedir => '/data/export/SOFTWARE/runtime',
-                    configfile => '/etc/arc.conf',
+    my $options = { 
+        controldir => '/var/spool/nordugrid',
     };
     require Data::Dumper; import Data::Dumper qw(Dumper);
     LogUtils::level('VERBOSE');
