@@ -4,12 +4,12 @@
 
 // perftest_deleg_bysechandler.cpp
 
+#include <chrono>
+#include <cmath>
 #include <iostream>
-#include <fstream>
+#include <mutex>
 #include <string>
-#include <stdlib.h>
-#include <glibmm/thread.h>
-#include <glibmm/timer.h>
+#include <thread>
 
 #include <arc/GUID.h>
 #include <arc/ArcConfig.h>
@@ -20,15 +20,15 @@
 #include <arc/communication/ClientInterface.h>
 
 // Some global shared variables...
-Glib::Mutex* mutex;
+std::mutex mutex;
 bool run;
 int finishedThreads;
 unsigned long completedRequests;
 unsigned long failedRequests;
 unsigned long totalRequests;
-Glib::TimeVal completedTime;
-Glib::TimeVal failedTime;
-Glib::TimeVal totalTime;
+std::chrono::system_clock::duration completedTime;
+std::chrono::system_clock::duration failedTime;
+std::chrono::system_clock::duration totalTime;
 std::string url_str;
 
 Arc::XMLNode sechanlder_nd("\
@@ -46,21 +46,13 @@ Arc::XMLNode sechanlder_nd("\
     <CACertificatesDir>../echo/certificates</CACertificatesDir>\
   </SecHandler>");
 
-
-// Round off a double to an integer.
-int Round(double x){
-  return int(x+0.5);
-}
-
 // Send requests and collect statistics.
 void sendRequests(){
   // Some variables...
   unsigned long completedRequests = 0;
   unsigned long failedRequests = 0;
-  Glib::TimeVal completedTime(0,0);
-  Glib::TimeVal failedTime(0,0);
-  Glib::TimeVal tBefore;
-  Glib::TimeVal tAfter;
+  std::chrono::system_clock::duration completedTime(0);
+  std::chrono::system_clock::duration failedTime(0);
   bool connected;
 
   //std::string url_str("https://127.0.0.1:60000/echo");
@@ -73,9 +65,9 @@ void sendRequests(){
   mcc_cfg.AddCADir("../echo/certificates");
 
   Arc::NS echo_ns; echo_ns["echo"]="http://www.nordugrid.org/schemas/echo";
-  
+
   while(run){
-    
+
     // Create a Client.
     Arc::ClientSOAP *client = NULL;
     client = new Arc::ClientSOAP(mcc_cfg,url,60);
@@ -88,7 +80,7 @@ void sendRequests(){
       req.NewChild("echo").NewChild("say")="HELLO";
 
       // Send the request and time it.
-      tBefore.assign_current_time();
+      auto tBefore = std::chrono::system_clock::now();
       Arc::PayloadSOAP* resp = NULL;
 
       //std::string str;
@@ -96,15 +88,15 @@ void sendRequests(){
       //std::cout<<"request: "<<str<<std::endl;
       Arc::MCC_Status status = client->process(&req,&resp);
 
-      tAfter.assign_current_time();
-      
+      auto tAfter = std::chrono::system_clock::now();
+
       if(!status) {
         // Request failed.
         failedRequests++;
         failedTime+=tAfter-tBefore;
-	    connected=false;
+        connected=false;
 
-          std::cout<<"failure1: "<<std::endl;
+        std::cout<<"failure1: "<<std::endl;
 
       } else {
         if(resp == NULL) {
@@ -138,7 +130,7 @@ void sendRequests(){
   }
 
   // Update global variables.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   ::completedRequests+=completedRequests;
   ::failedRequests+=failedRequests;
   ::completedTime+=completedTime;
@@ -152,12 +144,11 @@ int main(int argc, char* argv[]){
   int numberOfThreads;
   int duration;
   int i;
-  Glib::Thread** threads;
+  std::thread* threads;
   const char* config_file = NULL;
   int debug_level = -1;
   Arc::LogStream logcerr(std::cerr);
 
-  // Process options - quick hack, must use Glib options later
   while(argc >= 3) {
     if(strcmp(argv[1],"-c") == 0) {
       config_file = argv[2];
@@ -168,7 +159,7 @@ int main(int argc, char* argv[]){
     } else {
       break;
     };
-  } 
+  }
   if(debug_level >= 0) {
     Arc::Logger::getRootLogger().setThreshold((Arc::LogLevel)debug_level);
     Arc::Logger::getRootLogger().addDestination(logcerr);
@@ -176,18 +167,18 @@ int main(int argc, char* argv[]){
   // Extract command line arguments.
   if (argc!=4){
     std::cerr << "Wrong number of arguments!" << std::endl
-	      << std::endl
-	      << "Usage:" << std::endl
-	      << "perftest_deleg_bysechandler [-c config] [-d debug] url threads duration" << std::endl
-	      << std::endl
-	      << "Arguments:" << std::endl
-	      << "url     The url of the service." << std::endl
-	      << "threads  The number of concurrent requests." << std::endl
-	      << "duration The duration of the test in seconds." << std::endl
-	      << "config   The file containing client chain XML configuration with " << std::endl
+              << std::endl
+              << "Usage:" << std::endl
+              << "perftest_deleg_bysechandler [-c config] [-d debug] url threads duration" << std::endl
+              << std::endl
+              << "Arguments:" << std::endl
+              << "url     The url of the service." << std::endl
+              << "threads  The number of concurrent requests." << std::endl
+              << "duration The duration of the test in seconds." << std::endl
+              << "config   The file containing client chain XML configuration with " << std::endl
               << "         'soap' entry point and HOSTNAME, PORTNUMBER and PATH " << std::endl
               << "         keyword for hostname, port and HTTP path of 'echo' service." << std::endl
-	      << "debug    The textual representation of desired debug level. Available " << std::endl
+              << "debug    The textual representation of desired debug level. Available " << std::endl
               << "         levels: DEBUG, VERBOSE, INFO, WARNING, ERROR, FATAL." << std::endl;
     exit(EXIT_FAILURE);
   }
@@ -198,55 +189,53 @@ int main(int argc, char* argv[]){
   // Start threads.
   run=true;
   finishedThreads=0;
-  //Glib::thread_init();
-  mutex=new Glib::Mutex;
-  threads = new Glib::Thread*[numberOfThreads];
+  threads = new std::thread[numberOfThreads];
   for (i=0; i<numberOfThreads; i++)
-    threads[i]=Glib::Thread::create(sigc::ptr_fun(sendRequests),true);
+    threads[i] = std::thread(sendRequests);
 
   // Sleep while the threads are working.
-  Glib::usleep(duration*1000000);
+  std::this_thread::sleep_for(std::chrono::seconds(duration));
 
   // Stop the threads
   run=false;
   while(finishedThreads<numberOfThreads)
-    Glib::usleep(100000);
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
   // Print the result of the test.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   totalRequests = completedRequests+failedRequests;
   totalTime = completedTime+failedTime;
   std::cout << "========================================" << std::endl;
   std::cout << "URL: "
-	    << url_str << std::endl;
+            << url_str << std::endl;
   std::cout << "Number of threads: "
-	    << numberOfThreads << std::endl;
+            << numberOfThreads << std::endl;
   std::cout << "Duration: "
-	    << duration << " s" << std::endl;
+            << duration << " s" << std::endl;
   std::cout << "Number of requests: "
-	    << totalRequests << std::endl;
+            << totalRequests << std::endl;
   std::cout << "Completed requests: "
-	    << completedRequests << " ("
-	    << Round(completedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << completedRequests << " ("
+            << rint(completedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Failed requests: "
-	    << failedRequests << " ("
-	    << Round(failedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << failedRequests << " ("
+            << rint(failedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Completed requests per min: "
-            << Round(((double)completedRequests)/duration*60)
+            << rint((double)completedRequests / duration * 60)
             << std::endl;
   std::cout << "Average response time for all requests: "
-	    << Round(1000*totalTime.as_double()/totalRequests)
-	    << " ms" << std::endl;
+            << rint(std::chrono::duration<double, std::milli>(totalTime).count() / totalRequests)
+            << " ms" << std::endl;
   if (completedRequests!=0)
     std::cout << "Average response time for completed requests: "
-	      << Round(1000*completedTime.as_double()/completedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(completedTime).count() / completedRequests)
+              << " ms" << std::endl;
   if (failedRequests!=0)
     std::cout << "Average response time for failed requests: "
-	      << Round(1000*failedTime.as_double()/failedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(failedTime).count() / failedRequests)
+              << " ms" << std::endl;
   std::cout << "========================================" << std::endl;
 
   return 0;
