@@ -4,12 +4,12 @@
 
 // perftest_samlaa.cpp
 
+#include <chrono>
+#include <cmath>
 #include <iostream>
-#include <fstream>
+#include <mutex>
 #include <string>
-#include <stdlib.h>
-#include <glibmm/thread.h>
-#include <glibmm/timer.h>
+#include <thread>
 
 #include <arc/GUID.h>
 #include <arc/ArcConfig.h>
@@ -25,15 +25,15 @@
 #include <arc/xmlsec/XMLSecNode.h>
 
 // Some global shared variables...
-Glib::Mutex* mutex;
+std::mutex mutex;
 bool run;
 int finishedThreads;
 unsigned long completedRequests;
 unsigned long failedRequests;
 unsigned long totalRequests;
-Glib::TimeVal completedTime;
-Glib::TimeVal failedTime;
-Glib::TimeVal totalTime;
+std::chrono::system_clock::duration completedTime;
+std::chrono::system_clock::duration failedTime;
+std::chrono::system_clock::duration totalTime;
 std::string url_str;
 bool alwaysReconnect = false;
 
@@ -45,13 +45,8 @@ static std::string cadir("../../tests/echo/certificates");
 #define SAML_NAMESPACE "urn:oasis:names:tc:SAML:2.0:assertion"
 #define SAMLP_NAMESPACE "urn:oasis:names:tc:SAML:2.0:protocol"
 
-// Round off a double to an integer.
-int Round(double x){
-  return int(x+0.5);
-}
-
 static void prepareAttributeQuery(Arc::XMLNode& attr_query){
-  Arc::Credential cred(cert, key, cadir, cafile, false);
+  Arc::Credential cred(cert, key, cadir, cafile, false, true);
   std::string local_dn_str = cred.GetDN();
   std::string local_dn;
   size_t pos1 = std::string::npos;
@@ -147,10 +142,8 @@ void sendRequests(){
   // Some variables...
   unsigned long completedRequests = 0;
   unsigned long failedRequests = 0;
-  Glib::TimeVal completedTime(0,0);
-  Glib::TimeVal failedTime(0,0);
-  Glib::TimeVal tBefore;
-  Glib::TimeVal tAfter;
+  std::chrono::system_clock::duration completedTime(0);
+  std::chrono::system_clock::duration failedTime(0);
   bool connected;
 
   //std::string url_str("https://127.0.0.1:60000/echo");
@@ -171,11 +164,11 @@ void sendRequests(){
   Arc::NS saml_ns;
   saml_ns["saml"] = SAML_NAMESPACE;
   saml_ns["samlp"] = SAMLP_NAMESPACE;
- 
+
   Arc::init_xmlsec();
- 
+
   while(run){
-    
+
     // Create a Client.
     Arc::ClientSOAP *client = NULL;
     client = new Arc::ClientSOAP(mcc_cfg,url,60);
@@ -194,13 +187,13 @@ void sendRequests(){
       //std::cout<<"SOAP request: "<<tmp<<std::endl<<std::endl;
 
       // Send the request and time it.
-      tBefore.assign_current_time();
+      auto tBefore = std::chrono::system_clock::now();
       Arc::PayloadSOAP* resp = NULL;
 
       Arc::MCC_Status status = client->process(&req,&resp);
 
-      tAfter.assign_current_time();
-      
+      auto tAfter = std::chrono::system_clock::now();
+
       if(!status) {
         // Request failed.
         failedRequests++;
@@ -237,7 +230,7 @@ void sendRequests(){
   Arc::final_xmlsec();
 
   // Update global variables.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   ::completedRequests+=completedRequests;
   ::failedRequests+=failedRequests;
   ::completedTime+=completedTime;
@@ -251,12 +244,11 @@ int main(int argc, char* argv[]){
   int numberOfThreads;
   int duration;
   int i;
-  Glib::Thread** threads;
+  std::thread* threads;
   const char* config_file = NULL;
   int debug_level = -1;
   Arc::LogStream logcerr(std::cerr);
 
-  // Process options - quick hack, must use Glib options later
   while(argc >= 3) {
     if(strcmp(argv[1],"-c") == 0) {
       config_file = argv[2];
@@ -269,7 +261,7 @@ int main(int argc, char* argv[]){
     } else {
       break;
     };
-  } 
+  }
   if(debug_level >= 0) {
     Arc::Logger::getRootLogger().setThreshold((Arc::LogLevel)debug_level);
     Arc::Logger::getRootLogger().addDestination(logcerr);
@@ -277,20 +269,20 @@ int main(int argc, char* argv[]){
   // Extract command line arguments.
   if (argc!=4){
     std::cerr << "Wrong number of arguments!" << std::endl
-	      << std::endl
-	      << "Usage:" << std::endl
-	      << "perftest [-c config] [-d debug] [-r] url threads duration" << std::endl
-	      << std::endl
-	      << "Arguments:" << std::endl
-	      << "url       The url of the service." << std::endl
-	      << "threads   The number of concurrent requests." << std::endl
-	      << "duration  The duration of the test in seconds." << std::endl
-	      << "-c config The file containing client chain XML configuration with " << std::endl
+              << std::endl
+              << "Usage:" << std::endl
+              << "perftest [-c config] [-d debug] [-r] url threads duration" << std::endl
+              << std::endl
+              << "Arguments:" << std::endl
+              << "url       The url of the service." << std::endl
+              << "threads   The number of concurrent requests." << std::endl
+              << "duration  The duration of the test in seconds." << std::endl
+              << "-c config The file containing client chain XML configuration with " << std::endl
               << "          'soap' entry point and HOSTNAME, PORTNUMBER and PATH " << std::endl
               << "           keyword for hostname, port and HTTP path of 'echo' service." << std::endl
-	      << "-d debug   The textual representation of desired debug level. Available " << std::endl
+              << "-d debug   The textual representation of desired debug level. Available " << std::endl
               << "           levels: DEBUG, VERBOSE, INFO, WARNING, ERROR, FATAL." << std::endl
-	      << "-r         If specified close connection and reconnect after " << std::endl
+              << "-r         If specified close connection and reconnect after " << std::endl
               << "           every request." << std::endl;
     exit(EXIT_FAILURE);
   }
@@ -301,55 +293,53 @@ int main(int argc, char* argv[]){
   // Start threads.
   run=true;
   finishedThreads=0;
-  //Glib::thread_init();
-  mutex=new Glib::Mutex;
-  threads = new Glib::Thread*[numberOfThreads];
+  threads = new std::thread[numberOfThreads];
   for (i=0; i<numberOfThreads; i++)
-    threads[i]=Glib::Thread::create(sigc::ptr_fun(sendRequests),true);
+    threads[i] = std::thread(sendRequests);
 
   // Sleep while the threads are working.
-  Glib::usleep(duration*1000000);
+  std::this_thread::sleep_for(std::chrono::seconds(duration));
 
   // Stop the threads
   run=false;
   while(finishedThreads<numberOfThreads)
-    Glib::usleep(100000);
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
   // Print the result of the test.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   totalRequests = completedRequests+failedRequests;
   totalTime = completedTime+failedTime;
   std::cout << "========================================" << std::endl;
   std::cout << "URL: "
-	    << url_str << std::endl;
+            << url_str << std::endl;
   std::cout << "Number of threads: "
-	    << numberOfThreads << std::endl;
+            << numberOfThreads << std::endl;
   std::cout << "Duration: "
-	    << duration << " s" << std::endl;
+            << duration << " s" << std::endl;
   std::cout << "Number of requests: "
-	    << totalRequests << std::endl;
+            << totalRequests << std::endl;
   std::cout << "Completed requests: "
-	    << completedRequests << " ("
-	    << Round(completedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << completedRequests << " ("
+            << rint(completedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Failed requests: "
-	    << failedRequests << " ("
-	    << Round(failedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << failedRequests << " ("
+            << rint(failedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Completed requests per second: "
-            << Round(completedRequests/duration)
+            << rint((double)completedRequests / duration)
             << std::endl;
   std::cout << "Average response time for all requests: "
-	    << Round(1000*totalTime.as_double()/totalRequests)
-	    << " ms" << std::endl;
+            << rint(std::chrono::duration<double, std::milli>(totalTime).count() / totalRequests)
+            << " ms" << std::endl;
   if (completedRequests!=0)
     std::cout << "Average response time for completed requests: "
-	      << Round(1000*completedTime.as_double()/completedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(completedTime).count() / completedRequests)
+              << " ms" << std::endl;
   if (failedRequests!=0)
     std::cout << "Average response time for failed requests: "
-	      << Round(1000*failedTime.as_double()/failedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(failedTime).count() / failedRequests)
+              << " ms" << std::endl;
   std::cout << "========================================" << std::endl;
 
   return 0;
