@@ -4,12 +4,12 @@
 
 // perftest_slcs.cpp
 
+#include <chrono>
+#include <cmath>
 #include <iostream>
-#include <fstream>
+#include <mutex>
 #include <string>
-#include <stdlib.h>
-#include <glibmm/thread.h>
-#include <glibmm/timer.h>
+#include <thread>
 
 #include <arc/GUID.h>
 #include <arc/ArcConfig.h>
@@ -24,34 +24,27 @@
 #include <arc/xmlsec/XmlSecUtils.h>
 
 // Some global shared variables...
-Glib::Mutex* mutex;
+std::mutex mutex;
 bool run;
 int finishedThreads;
 unsigned long completedRequests;
 unsigned long failedRequests;
 unsigned long totalRequests;
-Glib::TimeVal completedTime;
-Glib::TimeVal failedTime;
-Glib::TimeVal totalTime;
+std::chrono::system_clock::duration completedTime;
+std::chrono::system_clock::duration failedTime;
+std::chrono::system_clock::duration totalTime;
 std::string url_str;
 std::string idp_name;
 std::string username;
 std::string password;
 
-// Round off a double to an integer.
-int Round(double x){
-  return int(x+0.5);
-}
-
 // Send requests and collect statistics.
 void sendRequests(){
   // Some variables...
   unsigned long completedRequests = 0;
   unsigned long failedRequests = 0;
-  Glib::TimeVal completedTime(0,0);
-  Glib::TimeVal failedTime(0,0);
-  Glib::TimeVal tBefore;
-  Glib::TimeVal tAfter;
+  std::chrono::system_clock::duration completedTime(0);
+  std::chrono::system_clock::duration failedTime(0);
   bool connected;
 
   Arc::URL url(url_str);
@@ -62,7 +55,7 @@ void sendRequests(){
 
   Arc::NS slcs_ns;
   slcs_ns["slcs"] = "http://www.nordugrid.org/schemas/slcs";
- 
+
   while(run){
     // Create a Client.
     Arc::ClientSOAPwithSAML2SSO *client = NULL;
@@ -73,7 +66,7 @@ void sendRequests(){
       // Prepare the request and time it.
       Arc::PayloadSOAP req(slcs_ns);
 
-      tBefore.assign_current_time();
+      auto tBefore = std::chrono::system_clock::now();
 
       Arc::Time t;
       int lifetime = 12;
@@ -92,13 +85,13 @@ void sendRequests(){
       Arc::PayloadSOAP* resp = NULL;
       Arc::MCC_Status status = client->process(&req,&resp, idp_name, username, password);
 
-      tAfter.assign_current_time();
- 
+      auto tAfter = std::chrono::system_clock::now();
+
       if(!status) {
         // Request failed.
         failedRequests++;
         failedTime+=tAfter-tBefore;
-	connected=false;
+        connected=false;
       } else {
         if(resp == NULL) {
           // Response was not SOAP or no response at all.
@@ -116,7 +109,7 @@ void sendRequests(){
             // Everything worked just fine!
             completedRequests++;
             completedTime+=tAfter-tBefore;
-          
+
             std::string cert_str = (std::string)((*resp)["GetSLCSCertificateResponse"]["X509Certificate"]);
             std::string ca_str = (std::string)((*resp)["GetSLCSCertificateResponse"]["CACertificate"]);
           }
@@ -128,7 +121,7 @@ void sendRequests(){
   }
 
   // Update global variables.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   ::completedRequests+=completedRequests;
   ::failedRequests+=failedRequests;
   ::completedTime+=completedTime;
@@ -142,12 +135,11 @@ int main(int argc, char* argv[]){
   int numberOfThreads;
   int duration;
   int i;
-  Glib::Thread** threads;
+  std::thread* threads;
   const char* config_file = NULL;
   int debug_level = -1;
   Arc::LogStream logcerr(std::cerr);
 
-  // Process options - quick hack, must use Glib options later
   while(argc >= 3) {
     if(strcmp(argv[1],"-c") == 0) {
       config_file = argv[2];
@@ -158,7 +150,7 @@ int main(int argc, char* argv[]){
     } else {
       break;
     };
-  } 
+  }
   if(debug_level >= 0) {
     Arc::Logger::getRootLogger().setThreshold((Arc::LogLevel)debug_level);
     Arc::Logger::getRootLogger().addDestination(logcerr);
@@ -166,21 +158,21 @@ int main(int argc, char* argv[]){
   // Extract command line arguments.
   if (argc!=7){
     std::cerr << "Wrong number of arguments!" << std::endl
-	      << std::endl
-	      << "Usage:" << std::endl
-	      << "perftest [-c config] [-d debug] url idpname username password threads duration" << std::endl
-	      << std::endl
-	      << "Arguments:" << std::endl
-	      << "url     The url of the slcs service." << std::endl
-              << "idpname   The name of the SP, e.g. https://squark.uio.no/idp/shibboleth" << std::endl
-              << "username  The username to IdP " << std::endl
-              << "password  The password to IdP   " << std::endl
-	      << "threads  The number of concurrent requests." << std::endl
-	      << "duration The duration of the test in seconds." << std::endl
-	      << "config   The file containing client chain XML configuration with " << std::endl
+              << std::endl
+              << "Usage:" << std::endl
+              << "perftest [-c config] [-d debug] url idpname username password threads duration" << std::endl
+              << std::endl
+              << "Arguments:" << std::endl
+              << "url      The url of the slcs service." << std::endl
+              << "idpname  The name of the SP, e.g. https://squark.uio.no/idp/shibboleth" << std::endl
+              << "username The username to IdP " << std::endl
+              << "password The password to IdP   " << std::endl
+              << "threads  The number of concurrent requests." << std::endl
+              << "duration The duration of the test in seconds." << std::endl
+              << "config   The file containing client chain XML configuration with " << std::endl
               << "         'soap' entry point and HOSTNAME, PORTNUMBER and PATH " << std::endl
               << "         keyword for hostname, port and HTTP path of 'echo' service." << std::endl
-	      << "debug    The textual representation of desired debug level. Available " << std::endl
+              << "debug    The textual representation of desired debug level. Available " << std::endl
               << "         levels: DEBUG, VERBOSE, INFO, WARNING, ERROR, FATAL." << std::endl;
     exit(EXIT_FAILURE);
   }
@@ -196,57 +188,53 @@ int main(int argc, char* argv[]){
   // Start threads.
   run=true;
   finishedThreads=0;
-  //Glib::thread_init();
-  mutex=new Glib::Mutex;
-  threads = new Glib::Thread*[numberOfThreads];
-  for (i=0; i<numberOfThreads; i++) {
-    threads[i]=Glib::Thread::create(sigc::ptr_fun(sendRequests),true);
-    //Glib::usleep(1000000);
-  }
+  threads = new std::thread[numberOfThreads];
+  for (i=0; i<numberOfThreads; i++)
+    threads[i] = std::thread(sendRequests);
 
   // Sleep while the threads are working.
-  Glib::usleep(duration*1000000);
+  std::this_thread::sleep_for(std::chrono::seconds(duration));
 
   // Stop the threads
   run=false;
   while(finishedThreads<numberOfThreads)
-    Glib::usleep(100000);
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
   // Print the result of the test.
-  Glib::Mutex::Lock lock(*mutex);
+  std::unique_lock<std::mutex> lock(mutex);
   totalRequests = completedRequests+failedRequests;
   totalTime = completedTime+failedTime;
   std::cout << "========================================" << std::endl;
   std::cout << "URL: "
-	    << url_str << std::endl;
+            << url_str << std::endl;
   std::cout << "Number of threads: "
-	    << numberOfThreads << std::endl;
+            << numberOfThreads << std::endl;
   std::cout << "Duration: "
-	    << duration << " s" << std::endl;
+            << duration << " s" << std::endl;
   std::cout << "Number of requests: "
-	    << totalRequests << std::endl;
+            << totalRequests << std::endl;
   std::cout << "Completed requests: "
-	    << completedRequests << " ("
-	    << Round(completedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << completedRequests << " ("
+            << rint(completedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Failed requests: "
-	    << failedRequests << " ("
-	    << Round(failedRequests*100.0/totalRequests)
-	    << "%)" << std::endl;
+            << failedRequests << " ("
+            << rint(failedRequests * 100.0 / totalRequests)
+            << "%)" << std::endl;
   std::cout << "Completed requests per min: "
-            << Round(((double)completedRequests)/duration*60)
+            << rint((double)completedRequests / duration * 60)
             << std::endl;
   std::cout << "Average response time for all requests: "
-	    << Round(1000*totalTime.as_double()/totalRequests)
-	    << " ms" << std::endl;
+            << rint(std::chrono::duration<double, std::milli>(totalTime).count() / totalRequests)
+            << " ms" << std::endl;
   if (completedRequests!=0)
     std::cout << "Average response time for completed requests: "
-	      << Round(1000*completedTime.as_double()/completedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(completedTime).count() / completedRequests)
+              << " ms" << std::endl;
   if (failedRequests!=0)
     std::cout << "Average response time for failed requests: "
-	      << Round(1000*failedTime.as_double()/failedRequests)
-	      << " ms" << std::endl;
+              << rint(std::chrono::duration<double, std::milli>(failedTime).count() / failedRequests)
+              << " ms" << std::endl;
   std::cout << "========================================" << std::endl;
 
   Arc::final_xmlsec();
