@@ -140,6 +140,8 @@ def is_multivalued(reference_f, reqblock, reqoption):
     for line in get_option_description(reference_f, reqblock, reqoption):
         if line.startswith('## multivalued'):
             return True
+        if line.startswith('## sequenced'):
+            return True
     return False
 
 
@@ -162,6 +164,8 @@ __rst_top_header = """\
 ARC Configuration Reference Document
 ************************************
 
+.. role:: blockhint
+
 General configuration structure
 ===============================
 
@@ -174,8 +178,7 @@ Configuration blocks and options
 """
 
 __rst_skiplist = [
-    '## WARNING: this file will not work as a configuration template',
-    '## NEVER USE THIS DOCUMENT AS A CONFIGURATION FILE',
+    '##!'
 ]
 
 __rst_replacelist = [
@@ -264,6 +267,7 @@ def reference2rst(reference_f, headers=True, block_label_prefix=''):
                     sys.stdout.write(opt_label.replace('/', '_'))
                     sys.stdout.write(optname + '\n')
                     sys.stdout.write('~' * len(optname) + '\n\n')
+                    sys.stdout.write(':blockhint:`[' + block_name + ']`\n\n')
                     # synopsis and string separated by dash
                     dash_pos = sline.find('-')
                     __rst_infotype('Synopsis')
